<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Stortech Pro
 * @since Stortech Pro 1.0.0
 */

/**
 * Check if Introduction  design section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_other_design_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[home_layout]' )->value();
	return ( 'ten-design' == $content_type );
}

if ( ! function_exists( 'stortech_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Stortech Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function stortech_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'stortech_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'stortech_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Stortech Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function stortech_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'stortech_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'stortech_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Stortech Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function stortech_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'stortech_pro_theme_options[pagination_enable]' )->value();
	}
endif;

if ( ! function_exists( 'stortech_pro_is_static_homepage_enable' ) ) :
	/**
	 * Check if static homepage is enabled.
	 *
	 * @since Stortech Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function stortech_pro_is_static_homepage_enable( $control ) {
		return ( 'page' == $control->manager->get_setting( 'show_on_front' )->value() );
	}
endif;

/**
 * Front Page Active Callbacks
 */

/**
 * Check if topbar section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_topbar_section_enable( $control ) {
	return ( $control->manager->get_setting( 'stortech_pro_theme_options[topbar_section_enable]' )->value() );
}

/**
 * Check if about section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_latest_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'stortech_pro_theme_options[latest_product_section_enable]' )->value() );
}

/**
 * Check if featured_product section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_featured_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'stortech_pro_theme_options[featured_product_section_enable]' )->value() );
}

/**
 * Check if featured_product section content type is category.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_featured_product_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[featured_product_content_type]' )->value();
	return stortech_pro_is_featured_product_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if featured_product section content type is page.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_featured_product_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[featured_product_content_type]' )->value();
	return stortech_pro_is_featured_product_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if featured_product section content type is post.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_featured_product_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[featured_product_content_type]' )->value();
	return stortech_pro_is_featured_product_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if team section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_trending_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'stortech_pro_theme_options[trending_product_section_enable]' )->value() );
}

/**
 * Check if trending_product section content type is post.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */

function stortech_pro_is_trending_product_section_content_category_enable_1( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[trending_content_type_1]' )->value();
	return stortech_pro_is_trending_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}

function stortech_pro_is_trending_product_section_content_category_enable_2( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[trending_content_type_2]' )->value();
	return stortech_pro_is_trending_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}

function stortech_pro_is_trending_product_section_content_category_enable_3( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[trending_content_type_3]' )->value();
	return stortech_pro_is_trending_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}

function stortech_pro_is_trending_product_section_content_product_enable_1( $control ) {
		$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[trending_content_type_1]' )->value();
	return stortech_pro_is_trending_product_section_enable( $control ) && ( 'product' == $content_type );
}

function stortech_pro_is_trending_product_section_content_product_enable_2( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[trending_content_type_2]' )->value();
	return stortech_pro_is_trending_product_section_enable( $control ) && ( 'product' == $content_type );
}

function stortech_pro_is_trending_product_section_content_product_enable_3( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[trending_content_type_3]' )->value();
	return stortech_pro_is_trending_product_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if partner section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_partner_section_enable( $control ) {
	return ( $control->manager->get_setting( 'stortech_pro_theme_options[partner_section_enable]' )->value() );
}

/**
 * Check if partner section content type is category.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_partner_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[partner_content_type]' )->value();
	return stortech_pro_is_partner_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if partner section content type is page.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_partner_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[partner_content_type]' )->value();
	return stortech_pro_is_partner_section_enable( $control ) && ( 'page' == $content_type );
}

/*
 * Check if partner section content type is post.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
 
function stortech_pro_is_partner_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[partner_content_type]' )->value();
	return stortech_pro_is_partner_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if partner section content type is recent.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_partner_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[partner_content_type]' )->value();
	return stortech_pro_is_partner_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if testimonial section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_testimonial_section_enable( $control ) {
	return ( $control->manager->get_setting( 'stortech_pro_theme_options[testimonial_section_enable]' )->value() );
}

/**
 * Check if testimonial section seperator.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_testimonial_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[testimonial_content_type]' )->value();
	return stortech_pro_is_testimonial_section_enable( $control ) && ( 'category' !== $content_type );
}

/**
 * Check if testimonial section content type is post.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_testimonial_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[testimonial_content_type]' )->value();
	return stortech_pro_is_testimonial_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if testimonial section content type is page.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_testimonial_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[testimonial_content_type]' )->value();
	return stortech_pro_is_testimonial_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if testimonial section content type is category.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_testimonial_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[testimonial_content_type]' )->value();
	return stortech_pro_is_testimonial_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if testimonial section content type is position.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_testimonial_section_content_position_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[testimonial_content_type]' )->value();
	return stortech_pro_is_testimonial_section_enable( $control ) && ( 'category' !== $content_type && 'tp-testimonial' !== $content_type );
}

/**
 * Check if testimonial section content type is custom.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_testimonial_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[testimonial_content_type]' )->value();
	return stortech_pro_is_testimonial_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if Featured Blog section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'stortech_pro_theme_options[blog_section_enable]' )->value() );
}

/**
 * Check if blog section content type is post.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_blog_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[blog_content_type]' )->value();
	return stortech_pro_is_blog_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog section content type is page.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_blog_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[blog_content_type]' )->value();
	return stortech_pro_is_blog_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section content type is category.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[blog_content_type]' )->value();
	return stortech_pro_is_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section content type is recent.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_blog_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[blog_content_type]' )->value();
	return stortech_pro_is_blog_section_enable( $control ) && ( 'recent' == $content_type );
}

/**
 * Check if testimonial section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_subscription_section_enable( $control ) {
	return ( $control->manager->get_setting( 'stortech_pro_theme_options[subscription_section_enable]' )->value() );
}

//======================================================================//

/**
 * Check if News Notice section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_news_notice_section_enable( $control ) {
	return ( $control->manager->get_setting( 'stortech_pro_theme_options[news_notice_section_enable]' )->value() );
}

/**
 * Check if slider section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'stortech_pro_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if slider section content type is category.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[slider_content_type]' )->value();
	return stortech_pro_is_slider_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if slider section content type is page.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[slider_content_type]' )->value();
	return stortech_pro_is_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is post.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[slider_content_type]' )->value();
	return stortech_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}



function stortech_pro_is_slider_product_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[slider_content_type]' )->value();
	return stortech_pro_is_slider_section_enable( $control ) && ( 'product' == $content_type );
}

function stortech_pro_is_slider_product_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[slider_content_type]' )->value();
	return stortech_pro_is_slider_section_enable( $control ) && ( 'product_cat' == $content_type );
}

//--------------featured section------------------------//

/**
 * Check if featured section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_featured_section_enable( $control ) {
	return ( $control->manager->get_setting( 'stortech_pro_theme_options[featured_section_enable]' )->value() );
}

/**
 * Check if featured section content type is category.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_featured_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[featured_content_type]' )->value();
	return stortech_pro_is_featured_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if featured section content type is page.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_featured_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[featured_content_type]' )->value();
	return stortech_pro_is_featured_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if featured section content type is post.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_featured_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[featured_content_type]' )->value();
	return stortech_pro_is_featured_section_enable( $control ) && ( 'post' == $content_type );
}



function stortech_pro_is_featured_product_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[featured_content_type]' )->value();
	return stortech_pro_is_featured_section_enable( $control ) && ( 'product' == $content_type );
}

function stortech_pro_is_featured_product_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[featured_content_type]' )->value();
	return stortech_pro_is_featured_section_enable( $control ) && ( 'product-cat' == $content_type );
}

//--------------accessories section------------------------//

/**
 * Check if accessories section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_accessories_section_enable( $control ) {
	return ( $control->manager->get_setting( 'stortech_pro_theme_options[accessories_section_enable]' )->value() );
}

/**
 * Check if accessories section content type is category.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_accessories_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[accessories_content_type]' )->value();
	return stortech_pro_is_accessories_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if accessories section content type is page.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_accessories_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[accessories_content_type]' )->value();
	return stortech_pro_is_accessories_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if accessories section content type is post.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_accessories_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[accessories_content_type]' )->value();
	return stortech_pro_is_accessories_section_enable( $control ) && ( 'post' == $content_type );
}



function stortech_pro_is_accessories_product_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[accessories_content_type]' )->value();
	return stortech_pro_is_accessories_section_enable( $control ) && ( 'product' == $content_type );
}

function stortech_pro_is_accessories_product_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[accessories_content_type]' )->value();
	return stortech_pro_is_accessories_section_enable( $control ) && ( 'product-cat' == $content_type );
}

//--------------Home page Layout Option------------------------//

/**
 * Check if Introduction  design section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_first_design_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[home_layout]' )->value();
	return ( 'first-design' == $content_type );
}

/**
 * Check if Introduction  design section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_product_design_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[home_layout]' )->value();
	return in_array( $content_type, array( 'first-design', 'product' ) );
}

/**
 * Check if Introduction  design section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_second_fourth_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'stortech_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout,array( 'first-design', 'second-design','fourth-design'));
}
/**
 * Check if Introduction  design section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_fifth_first_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'stortech_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout,array('fifth-design','first-design'));
}
/**
 * Check if first second fourth fifth  design section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_first_second_fourth_fifth_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'stortech_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout,array('second-design','fourth-design','fifth-design','first-design'));
}
/**
 * Check if second fourth sixth  design section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_second_fourth_fifth_sixth_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'stortech_pro_theme_options[home_layout]' )->value();
	return in_array( $home_layout, array('first-design', 'second-design','fourth-design','fifth-design','sixth-design') );
}

/**
 * Check if Notice  design section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_notice_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'stortech_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout,array('second-design','fifth-design','first-design'));
}

/**
 * Check if youtube design is enabled.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_slider_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'stortech_pro_theme_options[home_layout]' )->value();
	return ( 'product' != $home_layout );
}

/**
 * Check if youtube design is enabled.
 *
 * @since Sociable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_services_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'stortech_pro_theme_options[home_layout]' )->value();
	return in_array( $home_layout, array('third-design','second-design','fourth-design','fifth-design', 'first-design' ));
}


/**
 * Check if introduction section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_slider_subtitle_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'stortech_pro_theme_options[home_layout]' )->value();
	return ( $control->manager->get_setting( 'stortech_pro_theme_options[slider_section_enable]' )->value() &&  in_array($home_layout,array('third-design','second-design','fourth-design','fifth-design')));
}

/**
 * Check if Introduction  design section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_third_design_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[home_layout]' )->value();
	return ( 'third-design' == $content_type || 'first-design' == $content_type );
}

/**
 * Check if Introduction  design section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_fifth_design_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[home_layout]' )->value();
	return in_array( $content_type, array( 'fifth-design', 'first-design' ) );
}

/**
 * Check if Introduction  design section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_sixth_design_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[home_layout]' )->value();
	return in_array( $content_type, array( 'first-design', 'sixth-design' ) );
}

//--------------introduction section------------------------//



/**
 * Check if introduction section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_introduction_section_enable( $control ) {
	return ( $control->manager->get_setting( 'stortech_pro_theme_options[introduction_section_enable]' )->value() );
}
/**
 * Check if introduction section content type is page.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_introduction_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[introduction_content_type]' )->value();
	return stortech_pro_is_introduction_section_enable( $control ) && ( 'page' == $content_type );
}

/** 
 * Check if introduction section content type is post.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_introduction_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[introduction_content_type]' )->value();
	return stortech_pro_is_introduction_section_enable( $control ) && ( 'post' == $content_type );
}



function stortech_pro_is_introduction_product_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[introduction_content_type]' )->value();
	return stortech_pro_is_introduction_section_enable( $control ) && ( 'product' == $content_type );
}

//--------------Product short Desc section------------------------//


/**
 * Check if introduction section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_product_layout_short_des_section_enable( $control ) {
	return ( $control->manager->get_setting( 'stortech_pro_theme_options[product_layout_short_des_section_enable]' )->value() );
}
/**
 * Check if product_layout_short_des section content type is page.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_product_layout_short_des_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[product_layout_short_des_content_type]' )->value();
	return stortech_pro_is_product_layout_short_des_section_enable( $control ) && ( 'page' == $content_type );
}

/** 
 * Check if product_layout_short_des section content type is post.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_product_layout_short_des_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[product_layout_short_des_content_type]' )->value();
	return stortech_pro_is_product_layout_short_des_section_enable( $control ) && ( 'post' == $content_type );
}

/** 
 * Check if product_layout_short_des section content type is post.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_product_layout_short_des_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[product_layout_short_des_content_type]' )->value();
	return stortech_pro_is_product_layout_short_des_section_enable( $control ) && ( 'custom' == $content_type );
}


//--------------Product CTA section------------------------//


/**
 * Check if PRoduct CTA section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_product_layout_cta_section_enable( $control ) {
	return ( $control->manager->get_setting( 'stortech_pro_theme_options[product_layout_cta_section_enable]' )->value() );
}
/**
 * Check if product_layout_cta section content type is page.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_product_layout_cta_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[product_layout_cta_content_type]' )->value();
	return stortech_pro_is_product_layout_cta_section_enable( $control ) && ( 'page' == $content_type );
}

/** 
 * Check if product_layout_cta section content type is post.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_product_layout_cta_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[product_layout_cta_content_type]' )->value();
	return stortech_pro_is_product_layout_cta_section_enable( $control ) && ( 'post' == $content_type );
}

/** 
 * Check if product_layout_cta section content type is post.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_product_layout_cta_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[product_layout_cta_content_type]' )->value();
	return stortech_pro_is_product_layout_cta_section_enable( $control ) && ( 'custom' == $content_type );
}

//--------------Product Gallery section------------------------//


/**
 * Check if Product Gallery section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_product_layout_gallery_section_enable( $control ) {
	return ( $control->manager->get_setting( 'stortech_pro_theme_options[product_layout_gallery_section_enable]' )->value() );
}
/**
 * Check if product_layout_gallery section content type is page.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_product_layout_gallery_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[product_layout_gallery_content_type]' )->value();
	return stortech_pro_is_product_layout_gallery_section_enable( $control ) && ( 'page' == $content_type );
}

/** 
 * Check if product_layout_gallery section content type is post.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_product_layout_gallery_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[product_layout_gallery_content_type]' )->value();
	return stortech_pro_is_product_layout_gallery_section_enable( $control ) && ( 'post' == $content_type );
}

/** 
 * Check if product_layout_gallery section content type is post.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_product_layout_gallery_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[product_layout_gallery_content_type]' )->value();
	return stortech_pro_is_product_layout_gallery_section_enable( $control ) && ( 'category' == $content_type );
}

//--------------Product Features section------------------------//


/**
 * Check if Product Features section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_product_layout_features_section_enable( $control ) {
	return ( $control->manager->get_setting( 'stortech_pro_theme_options[product_layout_features_section_enable]' )->value() );
}
/**
 * Check if product_layout_features section content type is page.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_product_layout_features_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[product_layout_features_content_type]' )->value();
	return stortech_pro_is_product_layout_features_section_enable( $control ) && ( 'page' == $content_type );
}

/** 
 * Check if product_layout_features section content type is post.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_product_layout_features_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[product_layout_features_content_type]' )->value();
	return stortech_pro_is_product_layout_features_section_enable( $control ) && ( 'post' == $content_type );
}

/** 
 * Check if product_layout_features section content type is post.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_product_layout_features_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[product_layout_features_content_type]' )->value();
	return stortech_pro_is_product_layout_features_section_enable( $control ) && ( 'category' == $content_type );
}


//--------------Product Design section------------------------//


/**
 * Check if Product Design section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_product_layout_design_section_enable( $control ) {
	return ( $control->manager->get_setting( 'stortech_pro_theme_options[product_layout_design_section_enable]' )->value() );
}
/**
 * Check if product_layout_design section content type is page.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_product_layout_design_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[product_layout_design_content_type]' )->value();
	return stortech_pro_is_product_layout_design_section_enable( $control ) && ( 'page' == $content_type );
}

/** 
 * Check if product_layout_design section content type is post.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_product_layout_design_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[product_layout_design_content_type]' )->value();
	return stortech_pro_is_product_layout_design_section_enable( $control ) && ( 'post' == $content_type );
}

/** 
 * Check if product_layout_design section content type is post.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_product_layout_design_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[product_layout_design_content_type]' )->value();
	return stortech_pro_is_product_layout_design_section_enable( $control ) && ( 'custom' == $content_type );
}


//--------------Product Zoom section------------------------//


/**
 * Check if Product Zoom section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_product_layout_zoom_section_enable( $control ) {
	return ( $control->manager->get_setting( 'stortech_pro_theme_options[product_layout_zoom_section_enable]' )->value() );
}
/**
 * Check if product_layout_zoom section content type is page.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_product_layout_zoom_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[product_layout_zoom_content_type]' )->value();
	return stortech_pro_is_product_layout_zoom_section_enable( $control ) && ( 'page' == $content_type );
}

/** 
 * Check if product_layout_zoom section content type is post.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_product_layout_zoom_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[product_layout_zoom_content_type]' )->value();
	return stortech_pro_is_product_layout_zoom_section_enable( $control ) && ( 'post' == $content_type );
}

/** 
 * Check if product_layout_zoom section content type is post.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_product_layout_zoom_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[product_layout_zoom_content_type]' )->value();
	return stortech_pro_is_product_layout_zoom_section_enable( $control ) && ( 'custom' == $content_type );
}

//--------------Product Similar section------------------------//

/**
 * Check if product_layout_similar_product section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_product_layout_similar_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'stortech_pro_theme_options[product_layout_similar_product_section_enable]' )->value() );
}

function stortech_pro_is_product_layout_similar_product_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[product_layout_similar_product_content_type]' )->value();
	return stortech_pro_is_product_layout_similar_product_section_enable( $control ) && ( 'product' == $content_type );
}

function stortech_pro_is_product_layout_similar_product_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[product_layout_similar_product_content_type]' )->value();
	return stortech_pro_is_product_layout_similar_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}

//--------------Second Design Masonry Product section------------------------//



/**
 * Check if masonry_product section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_masonry_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'stortech_pro_theme_options[masonry_product_section_enable]' )->value() );
}

/**
 * Check if masonry_product section content type is category.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_masonry_product_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[masonry_product_content_type]' )->value();
	return stortech_pro_is_masonry_product_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if masonry_product section content type is page.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_masonry_product_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[masonry_product_content_type]' )->value();
	return stortech_pro_is_masonry_product_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if masonry_product section content type is post.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_masonry_product_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[masonry_product_content_type]' )->value();
	return stortech_pro_is_masonry_product_section_enable( $control ) && ( 'post' == $content_type );
}



function stortech_pro_is_masonry_product_product_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[masonry_product_content_type]' )->value();
	return stortech_pro_is_masonry_product_section_enable( $control ) && ( 'product' == $content_type );
}

function stortech_pro_is_masonry_product_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[masonry_product_content_type]' )->value();
	return stortech_pro_is_masonry_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}

//--------------Recent Product section------------------------//

/**
 * Check if recent_product section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_recent_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'stortech_pro_theme_options[recent_product_section_enable]' )->value() );
}

function stortech_pro_is_recent_product_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[recent_product_content_type]' )->value();
	return stortech_pro_is_recent_product_section_enable( $control ) && ( 'product' == $content_type );
}

function stortech_pro_is_recent_product_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[recent_product_content_type]' )->value();
	return stortech_pro_is_recent_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}


//--------------Second Design Featured Product section------------------------//



/**
 * Check if second_featured_product section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_second_featured_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'stortech_pro_theme_options[second_featured_product_section_enable]' )->value() );
}

/**
 * Check if second_featured_product section content type is category.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_second_featured_product_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[second_featured_product_content_type]' )->value();
	return stortech_pro_is_second_featured_product_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if second_featured_product section content type is page.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_second_featured_product_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[second_featured_product_content_type]' )->value();
	return stortech_pro_is_second_featured_product_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if second_featured_product section content type is post.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_second_featured_product_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[second_featured_product_content_type]' )->value();
	return stortech_pro_is_second_featured_product_section_enable( $control ) && ( 'post' == $content_type );
}



function stortech_pro_is_second_featured_product_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[second_featured_product_content_type]' )->value();
	return stortech_pro_is_second_featured_product_section_enable( $control ) && ( 'product' == $content_type );
}

function stortech_pro_is_second_featured_product_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[second_featured_product_content_type]' )->value();
	return stortech_pro_is_second_featured_product_section_enable( $control ) && ( 'product-cat' == $content_type );
}


//--------------Popular Product section------------------------//

/**
 * Check if popular_product section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_popular_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'stortech_pro_theme_options[popular_product_section_enable]' )->value() );
}

function stortech_pro_is_popular_product_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[popular_product_content_type]' )->value();
	return stortech_pro_is_popular_product_section_enable( $control ) && ( 'product' == $content_type );
}

function stortech_pro_is_popular_product_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[popular_product_content_type]' )->value();
	return stortech_pro_is_popular_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}

//--------------Services section------------------------//


/**
/**
 * Check if services section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_services_section_enable( $control ) {
	return ( $control->manager->get_setting( 'stortech_pro_theme_options[services_section_enable]' )->value() );
}

/**
 * Check if services section content type is category.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_services_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[services_content_type]' )->value();
	return stortech_pro_is_services_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if services section content type is page.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_services_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[services_content_type]' )->value();
	return stortech_pro_is_services_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if services section content type is post.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_services_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[services_content_type]' )->value();
	return stortech_pro_is_services_section_enable( $control ) && ( 'post' == $content_type );
}

//--------------Third Design Product Collection section------------------------//

/**
 * Check if product_collection section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_product_collection_section_enable( $control ) {
	return ( $control->manager->get_setting( 'stortech_pro_theme_options[product_collection_section_enable]' )->value() );
}

/**
 * Check if product_collection section content type is category.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_product_collection_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[product_collection_content_type]' )->value();
	return stortech_pro_is_product_collection_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if product_collection section content type is page.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_product_collection_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[product_collection_content_type]' )->value();
	return stortech_pro_is_product_collection_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if product_collection section content type is post.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_product_collection_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[product_collection_content_type]' )->value();
	return stortech_pro_is_product_collection_section_enable( $control ) && ( 'post' == $content_type );
}


function stortech_pro_is_product_collection_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[product_collection_content_type]' )->value();
	return stortech_pro_is_product_collection_section_enable( $control ) && ( 'product' == $content_type );
}

function stortech_pro_is_product_collection_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[product_collection_content_type]' )->value();
	return stortech_pro_is_product_collection_section_enable( $control ) && ( 'product-cat' == $content_type );
}

//--------------Business About Us section------------------------//


/**
 * Check if Business About Us section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_about_us_section_enable( $control ) {
	return ( $control->manager->get_setting( 'stortech_pro_theme_options[about_us_section_enable]' )->value() );
}
/**
 * Check if about_us section content type is page.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_about_us_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[about_us_content_type]' )->value();
	return stortech_pro_is_about_us_section_enable( $control ) && ( 'page' == $content_type );
}

/** 
 * Check if about_us section content type is post.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_about_us_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[about_us_content_type]' )->value();
	return stortech_pro_is_about_us_section_enable( $control ) && ( 'post' == $content_type );
}

/** 
 * Check if about_us section content type is post.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_about_us_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[about_us_content_type]' )->value();
	return stortech_pro_is_about_us_section_enable( $control ) && ( 'custom' == $content_type );
}

//--------------Business counter section------------------------//

/**
 * Check if counter section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_counter_section_enable( $control ) {
	return ( $control->manager->get_setting( 'stortech_pro_theme_options[counter_section_enable]' )->value() );
}


//--------------Business Team section------------------------//

/**
 * Check if team section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_team_section_enable( $control ) {
	return ( $control->manager->get_setting( 'stortech_pro_theme_options[team_section_enable]' )->value() );
}

/**
 * Check if team section content type is post.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_team_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[team_content_type]' )->value();
	return stortech_pro_is_team_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if team section content type is custom.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_team_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[team_content_type]' )->value();
	return stortech_pro_is_team_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if team section seperator.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_team_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[team_content_type]' )->value();
	return stortech_pro_is_team_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if team section content type is page.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_team_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[team_content_type]' )->value();
	return stortech_pro_is_team_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if team section content type is category.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_team_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[team_content_type]' )->value();
	return stortech_pro_is_team_section_enable( $control ) && ( 'category' == $content_type );
}



/**
 * Check if Featured Blog section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_featured_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'stortech_pro_theme_options[featured_blog_section_enable]' )->value() );
}

/**
 * Check if featured_blog section content type is post.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_featured_blog_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[featured_blog_content_type]' )->value();
	return stortech_pro_is_featured_blog_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if featured_blog section content type is page.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_featured_blog_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[featured_blog_content_type]' )->value();
	return stortech_pro_is_featured_blog_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if featured_blog section content type is category.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_featured_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[featured_blog_content_type]' )->value();
	return stortech_pro_is_featured_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if featured_blog section content type is recent.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_featured_blog_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[featured_blog_content_type]' )->value();
	return stortech_pro_is_featured_blog_section_enable( $control ) && ( 'recent' == $content_type );
}


/**
 * Check if Featured Blog section is enabled.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_popular_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'stortech_pro_theme_options[popular_blog_section_enable]' )->value() );
}

/**
 * Check if popular_blog section content type is post.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_popular_blog_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[popular_blog_content_type]' )->value();
	return stortech_pro_is_popular_blog_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if popular_blog section content type is page.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_popular_blog_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[popular_blog_content_type]' )->value();
	return stortech_pro_is_popular_blog_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if popular_blog section content type is category.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_popular_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[popular_blog_content_type]' )->value();
	return stortech_pro_is_popular_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if popular_blog section content type is recent.
 *
 * @since Stortech Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function stortech_pro_is_popular_blog_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'stortech_pro_theme_options[popular_blog_content_type]' )->value();
	return stortech_pro_is_popular_blog_section_enable( $control ) && ( 'recent' == $content_type );
}