<?php
/**
 * About Us Section options
 *
 * @package Theme Palace
 * @subpackage Stortech Pro
 * @since Stortech Pro 1.0.0
 */

// Add About Us section
$wp_customize->add_section( 'stortech_pro_about_us_section', array(
	'title'             => esc_html__( ' Business About Us','stortech-pro' ),
	'description'       => esc_html__( 'About Us Section options.', 'stortech-pro' ),
	'panel'             => 'stortech_pro_front_page_panel',
	'active_callback'	=> 'stortech_pro_is_fifth_design_enable',
) );

// About Us content enable control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[about_us_section_enable]', array(
	'default'			=> 	$options['about_us_section_enable'],
	'sanitize_callback' => 'stortech_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Stortech_Pro_Switch_Control( $wp_customize, 'stortech_pro_theme_options[about_us_section_enable]', array(
	'label'             => esc_html__( 'About Us Section Enable', 'stortech-pro' ),
	'section'           => 'stortech_pro_about_us_section',
	'on_off_label' 		=> stortech_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'stortech_pro_theme_options[about_us_section_enable]', array(
		'selector'            => '#business-about-us .tooltiptext',
		'settings'            => 'stortech_pro_theme_options[about_us_section_enable]',
    ) );
}


// About Us content type control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[about_us_content_type]', array(
	'default'          	=> $options['about_us_content_type'],
	'sanitize_callback' => 'stortech_pro_sanitize_select',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[about_us_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'stortech-pro' ),
	'section'           => 'stortech_pro_about_us_section',
	'type'				=> 'select',
	'active_callback' 	=> 'stortech_pro_is_about_us_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'stortech-pro' ),
		'post' 		=> esc_html__( 'Post', 'stortech-pro' ),
		'custom' 		=> esc_html__( 'Custom', 'stortech-pro' ),
	),
) );


// about_us pages drop down chooser control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[about_us_content_page]', array(
	'sanitize_callback' => 'stortech_pro_sanitize_page',
) );

$wp_customize->add_control( new Stortech_Pro_Dropdown_Chooser( $wp_customize, 'stortech_pro_theme_options[about_us_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'stortech-pro' ), 
	'section'           => 'stortech_pro_about_us_section',
	'choices'			=> stortech_pro_page_choices(),
	'active_callback'	=> 'stortech_pro_is_about_us_section_content_page_enable',
) ) );

// about_us posts drop down chooser control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[about_us_content_post]', array(
	'sanitize_callback' => 'stortech_pro_sanitize_page',
) );

$wp_customize->add_control( new Stortech_Pro_Dropdown_Chooser( $wp_customize, 'stortech_pro_theme_options[about_us_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'stortech-pro' ), 
	'section'           => 'stortech_pro_about_us_section',
	'choices'			=> stortech_pro_post_choices(),
	'active_callback'	=> 'stortech_pro_is_about_us_section_content_post_enable',
) ) ); 

$wp_customize->add_setting( 'stortech_pro_theme_options[about_us_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[about_us_btn_label]', array(
	'label'           	=>  esc_html__( 'About Us Button Label', 'stortech-pro' ),
	'section'        	=> 'stortech_pro_about_us_section',
	'active_callback' 	=> 'stortech_pro_is_about_us_section_enable',
	'type'				=> 'text',
) );

$wp_customize->add_setting( 'stortech_pro_theme_options[about_us_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[about_us_btn_url]', array(
	'label'           	=>  esc_html__( 'About Us Button Link ', 'stortech-pro' ),
	'section'        	=> 'stortech_pro_about_us_section',
	'active_callback' 	=> 'stortech_pro_is_about_us_section_enable',
	'type'				=> 'url',
) );

// layout_zoom title setting and control
$wp_customize->add_setting( 'stortech_pro_theme_options[about_us_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_us_title'],
	'transport'			=> 'refresh',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[about_us_title]', array(
	'label'           	=> esc_html__( 'Title', 'stortech-pro' ),
	'section'        	=> 'stortech_pro_about_us_section',
	'active_callback' 	=> 'stortech_pro_is_about_us_section_content_custom_enable',
	'type'				=> 'text',
) );


// layout_zoom description setting and control
$wp_customize->add_setting( 'stortech_pro_theme_options[about_us_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['about_us_description'],
	'transport'			=> 'refresh',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[about_us_description]', array(
	'label'           	=> esc_html__( 'Description', 'stortech-pro' ),
	'section'        	=> 'stortech_pro_about_us_section',
	'active_callback' 	=> 'stortech_pro_is_about_us_section_content_custom_enable',
	'type'				=> 'textarea',
) );

// layout_zoom image setting and control.
$wp_customize->add_setting( 'stortech_pro_theme_options[about_us_image]', array(
	'sanitize_callback' => 'stortech_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'stortech_pro_theme_options[about_us_image]',
		array(
		'label'       		=> esc_html__( 'Image', 'stortech-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'stortech-pro' ), 1920, 1280 ),
		'section'     		=> 'stortech_pro_about_us_section',
		'active_callback'	=> 'stortech_pro_is_about_us_section_content_custom_enable',
) ) );
