<?php
/**
 * Featured Section options
 *
 * @package Theme Palace
 * @subpackage Stortech Pro
 * @since Stortech Pro 1.0.0
 */

// Add Featured section
$wp_customize->add_section( 'stortech_pro_featured_section', array(
	'title'             => esc_html__( 'Featured','stortech-pro' ),
	'description'       => esc_html__( 'Featured Section options.', 'stortech-pro' ),
	'panel'             => 'stortech_pro_front_page_panel',
	'active_callback'	=> 'stortech_pro_is_first_design_enable',
) );

// Featured content enable control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[featured_section_enable]', array(
	'default'			=> 	$options['featured_section_enable'],
	'sanitize_callback' => 'stortech_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Stortech_Pro_Switch_Control( $wp_customize, 'stortech_pro_theme_options[featured_section_enable]', array(
	'label'             => esc_html__( 'Featured Section Enable', 'stortech-pro' ),
	'section'           => 'stortech_pro_featured_section',
	'on_off_label' 		=> stortech_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'stortech_pro_theme_options[featured_section_enable]', array(
		'selector'            => '#featured .tooltiptext',
		'settings'            => 'stortech_pro_theme_options[featured_section_enable]',
    ) );
}


$wp_customize->add_setting( 'stortech_pro_theme_options[featured_btn_label]', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> $options['featured_btn_label'],
) );

$wp_customize->add_control( 'stortech_pro_theme_options[featured_btn_label]', array(
	'label'           	=> esc_html__( 'Featured Button Lable', 'stortech-pro' ),
	'section'        	=> 'stortech_pro_featured_section',
	'active_callback' 	=> 'stortech_pro_is_featured_section_enable',
	'type'				=> 'text',
) );


// Event social icons number control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[featured_count]', array(
	'default'          	=> $options['featured_count'],
	'sanitize_callback' => 'stortech_pro_sanitize_number_range',
	'validate_callback' => 'stortech_pro_validate_featured_count',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[featured_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'stortech-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'stortech-pro' ),
	'section'           => 'stortech_pro_featured_section',
	'active_callback'   => 'stortech_pro_is_featured_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

for( $i=1 ; $i<= $options['featured_count'] ; $i++ ) {

	$wp_customize->add_setting( 'stortech_pro_theme_options[featured_alt_btn_label_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'stortech_pro_theme_options[featured_alt_btn_label_'.$i.']', array(
		'label'           	=> sprintf( esc_html__( 'Featured Alternative Button Lable', 'stortech-pro' ), $i ),
		'section'        	=> 'stortech_pro_featured_section',
		'active_callback' 	=> 'stortech_pro_is_featured_section_enable',
		'type'				=> 'text',
	) );

	$wp_customize->add_setting( 'stortech_pro_theme_options[featured_btn_url_'.$i.']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'stortech_pro_theme_options[featured_btn_url_'.$i.']', array(
		'label'           	=> sprintf( esc_html__( 'Featured Button Link %d', 'stortech-pro' ), $i ),
		'section'        	=> 'stortech_pro_featured_section',
		'active_callback' 	=> 'stortech_pro_is_featured_section_enable',
		'type'				=> 'url',
	) );
}

$wp_customize->add_setting( 'stortech_pro_theme_options[featured_hr_2]', array(
	'sanitize_callback' => 'sanitize_text_field'

) );

$wp_customize->add_control( new Stortech_Pro_Customize_Horizontal_Line( $wp_customize, 'stortech_pro_theme_options[featured_hr_2]',
	array(
		'section'         => 'stortech_pro_featured_section',
		'active_callback' => 'stortech_pro_is_featured_section_enable',
		'type'			  => 'hr'
) ) );

// Featured content type control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[featured_content_type]', array(
	'default'          	=> $options['featured_content_type'],
	'sanitize_callback' => 'stortech_pro_sanitize_select',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[featured_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'stortech-pro' ),
	'section'           => 'stortech_pro_featured_section',
	'type'				=> 'select',
	'active_callback' 	=> 'stortech_pro_is_featured_section_enable',
	'choices'			=> stortech_pro_featured_product_content_type(),
) );

for ( $i = 1; $i <= $options['featured_count']; $i++ ) :
	// featured pages drop down chooser control and setting
	$wp_customize->add_setting( 'stortech_pro_theme_options[featured_content_page_' . $i . ']', array(
		'sanitize_callback' => 'stortech_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Stortech_Pro_Dropdown_Chooser( $wp_customize, 'stortech_pro_theme_options[featured_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'stortech-pro' ), $i ),
		'section'           => 'stortech_pro_featured_section',
		'choices'			=> stortech_pro_page_choices(),
		'active_callback'	=> 'stortech_pro_is_featured_section_content_page_enable',
	) ) );

	// featured posts drop down chooser control and setting
	$wp_customize->add_setting( 'stortech_pro_theme_options[featured_content_post_' . $i . ']', array(
		'sanitize_callback' => 'stortech_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Stortech_Pro_Dropdown_Chooser( $wp_customize, 'stortech_pro_theme_options[featured_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'stortech-pro' ), $i ),
		'section'           => 'stortech_pro_featured_section',
		'choices'			=> stortech_pro_post_choices(),
		'active_callback'	=> 'stortech_pro_is_featured_section_content_post_enable',
	) ) ); 

	$wp_customize->add_setting( 'stortech_pro_theme_options[featured_product_content_page_' . $i . ']', array(
		'sanitize_callback' => 'stortech_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Stortech_Pro_Dropdown_Chooser( $wp_customize, 'stortech_pro_theme_options[featured_product_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Product %d', 'stortech-pro' ), $i ),
		'section'           => 'stortech_pro_featured_section',
		'choices'			=> stortech_pro_product_choices(),
		'active_callback'	=> 'stortech_pro_is_featured_product_section_content_product_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'stortech_pro_theme_options[featured_content_category]', array(
	'sanitize_callback' => 'stortech_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Stortech_Pro_Dropdown_Taxonomy_Control( $wp_customize,'stortech_pro_theme_options[featured_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'stortech-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'stortech-pro' ),
	'section'           => 'stortech_pro_featured_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'stortech_pro_is_featured_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'stortech_pro_theme_options[featured_product_category]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Stortech_Pro_Dropdown_Taxonomies_Control( $wp_customize,'stortech_pro_theme_options[featured_product_category]', array(
	'label'             => esc_html__( 'Select Product Category', 'stortech-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'stortech-pro' ),
	'section'           => 'stortech_pro_featured_section',
	'taxonomy'			=> 'product_cat',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'stortech_pro_is_featured_product_section_content_product_category_enable'
) ) );

// stortech title setting and control
$wp_customize->add_setting( 'stortech_pro_theme_options[featured_product_text]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[featured_product_text]', array(
	'label'           	=> esc_html__( 'Product Text', 'stortech-pro' ),
	'section'        	=> 'stortech_pro_featured_section',
	'active_callback' 	=> 'stortech_pro_is_featured_product_section_content_product_enable',
	'type'				=> 'text',
) );