<?php
/**
 * Introduction Section options
 *
 * @package Theme Palace
 * @subpackage Stortech Pro
 * @since Stortech Pro 1.0.0
 */

// Add Introduction section
$wp_customize->add_section( 'stortech_pro_introduction_section', array(
	'title'             => esc_html__( 'Introduction','stortech-pro' ),
	'description'       => esc_html__( 'Introduction Section options.', 'stortech-pro' ),
	'panel'             => 'stortech_pro_front_page_panel',
	'active_callback'	=> 'stortech_pro_is_product_design_enable',
) );

// Introduction content enable control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[introduction_section_enable]', array(
	'default'			=> 	$options['introduction_section_enable'],
	'sanitize_callback' => 'stortech_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Stortech_Pro_Switch_Control( $wp_customize, 'stortech_pro_theme_options[introduction_section_enable]', array(
	'label'             => esc_html__( 'Introduction Section Enable', 'stortech-pro' ),
	'section'           => 'stortech_pro_introduction_section',
	'on_off_label' 		=> stortech_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'stortech_pro_theme_options[introduction_section_enable]', array(
		'selector'            => '#introduction .tooltiptext',
		'settings'            => 'stortech_pro_theme_options[introduction_section_enable]',
    ) );
}


// Introduction content type control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[introduction_content_type]', array(
	'default'          	=> $options['introduction_content_type'],
	'sanitize_callback' => 'stortech_pro_sanitize_select',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[introduction_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'stortech-pro' ),
	'section'           => 'stortech_pro_introduction_section',
	'type'				=> 'select',
	'active_callback' 	=> 'stortech_pro_is_introduction_section_enable',
	'choices'			=> stortech_pro_introduction_product_content_type(),
) );


// introduction pages drop down chooser control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[introduction_content_page]', array(
	'sanitize_callback' => 'stortech_pro_sanitize_page',
) );

$wp_customize->add_control( new Stortech_Pro_Dropdown_Chooser( $wp_customize, 'stortech_pro_theme_options[introduction_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'stortech-pro' ), 
	'section'           => 'stortech_pro_introduction_section',
	'choices'			=> stortech_pro_page_choices(),
	'active_callback'	=> 'stortech_pro_is_introduction_section_content_page_enable',
) ) );

// introduction posts drop down chooser control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[introduction_content_post]', array(
	'sanitize_callback' => 'stortech_pro_sanitize_page',
) );

$wp_customize->add_control( new Stortech_Pro_Dropdown_Chooser( $wp_customize, 'stortech_pro_theme_options[introduction_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'stortech-pro' ), 
	'section'           => 'stortech_pro_introduction_section',
	'choices'			=> stortech_pro_post_choices(),
	'active_callback'	=> 'stortech_pro_is_introduction_section_content_post_enable',
) ) ); 

$wp_customize->add_setting( 'stortech_pro_theme_options[introduction_product_content_page]', array(
	'sanitize_callback' => 'stortech_pro_sanitize_page',
) );

$wp_customize->add_control( new Stortech_Pro_Dropdown_Chooser( $wp_customize, 'stortech_pro_theme_options[introduction_product_content_page]', array(
	'label'             => esc_html__( 'Select Product', 'stortech-pro' ), 
	'section'           => 'stortech_pro_introduction_section',
	'choices'			=> stortech_pro_product_choices(),
	'active_callback'	=> 'stortech_pro_is_introduction_product_section_content_product_enable',
) ) );

// stortech title setting and control
$wp_customize->add_setting( 'stortech_pro_theme_options[introduction_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[introduction_subtitle]', array(
	'label'           	=> esc_html__( 'Subtitle', 'stortech-pro' ),
	'section'        	=> 'stortech_pro_introduction_section',
	'active_callback' 	=> 'stortech_pro_is_introduction_section_enable',
	'type'				=> 'text',
) );

// stortech title setting and control
$wp_customize->add_setting( 'stortech_pro_theme_options[introduction_product_text]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[introduction_product_text]', array(
	'label'           	=> esc_html__( 'Product Text', 'stortech-pro' ),
	'section'        	=> 'stortech_pro_introduction_section',
	'active_callback' 	=> 'stortech_pro_is_introduction_product_section_content_product_enable',
	'type'				=> 'text',
) );