<?php
/**
 * Masonry Product Section options
 *
 * @package Theme Palace
 * @subpackage Stortech Pro
 * @since Stortech Pro 1.0.0
 */

// Add Masonry Product section
$wp_customize->add_section( 'stortech_pro_masonry_product_section', array(
	'title'             => esc_html__( 'Masonry Product','stortech-pro' ),
	'description'       => esc_html__( 'Masonry Product Section options.', 'stortech-pro' ),
	'panel'             => 'stortech_pro_front_page_panel',
	'active_callback'	=> 'stortech_pro_is_second_fourth_design_enable',
) );

// Masonry Product content enable control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[masonry_product_section_enable]', array(
	'default'			=> 	$options['masonry_product_section_enable'],
	'sanitize_callback' => 'stortech_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Stortech_Pro_Switch_Control( $wp_customize, 'stortech_pro_theme_options[masonry_product_section_enable]', array(
	'label'             => esc_html__( 'Masonry Product Section Enable', 'stortech-pro' ),
	'section'           => 'stortech_pro_masonry_product_section',
	'on_off_label' 		=> stortech_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'stortech_pro_theme_options[masonry_product_section_enable]', array(
		'selector'            => '#masonry .tooltiptext',
		'settings'            => 'stortech_pro_theme_options[masonry_product_section_enable]',
    ) );
}



// Event social icons number control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[masonry_product_count]', array(
	'default'          	=> $options['masonry_product_count'],
	'sanitize_callback' => 'stortech_pro_sanitize_number_range',
	'validate_callback' => 'stortech_pro_validate_masonry_product_count',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[masonry_product_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'stortech-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'stortech-pro' ),
	'section'           => 'stortech_pro_masonry_product_section',
	'active_callback'   => 'stortech_pro_is_masonry_product_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );


// Masonry Product content type control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[masonry_product_content_type]', array(
	'default'          	=> $options['masonry_product_content_type'],
	'sanitize_callback' => 'stortech_pro_sanitize_select',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[masonry_product_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'stortech-pro' ),
	'section'           => 'stortech_pro_masonry_product_section',
	'type'				=> 'select',
	'active_callback' 	=> 'stortech_pro_is_masonry_product_section_enable',
	'choices'			=> stortech_pro_slider_product_content_type(),
) );

for ( $i = 1; $i <= $options['masonry_product_count']; $i++ ) :
	// masonry_product pages drop down chooser control and setting
	$wp_customize->add_setting( 'stortech_pro_theme_options[masonry_product_content_page_' . $i . ']', array(
		'sanitize_callback' => 'stortech_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Stortech_Pro_Dropdown_Chooser( $wp_customize, 'stortech_pro_theme_options[masonry_product_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'stortech-pro' ), $i ),
		'section'           => 'stortech_pro_masonry_product_section',
		'choices'			=> stortech_pro_page_choices(),
		'active_callback'	=> 'stortech_pro_is_masonry_product_section_content_page_enable',
	) ) );

	// masonry_product posts drop down chooser control and setting
	$wp_customize->add_setting( 'stortech_pro_theme_options[masonry_product_content_post_' . $i . ']', array(
		'sanitize_callback' => 'stortech_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Stortech_Pro_Dropdown_Chooser( $wp_customize, 'stortech_pro_theme_options[masonry_product_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'stortech-pro' ), $i ),
		'section'           => 'stortech_pro_masonry_product_section',
		'choices'			=> stortech_pro_post_choices(),
		'active_callback'	=> 'stortech_pro_is_masonry_product_section_content_post_enable',
	) ) ); 

	$wp_customize->add_setting( 'stortech_pro_theme_options[masonry_product_product_content_page_' . $i . ']', array(
		'sanitize_callback' => 'stortech_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Stortech_Pro_Dropdown_Chooser( $wp_customize, 'stortech_pro_theme_options[masonry_product_product_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Product %d', 'stortech-pro' ), $i ),
		'section'           => 'stortech_pro_masonry_product_section',
		'choices'			=> stortech_pro_product_choices(),
		'active_callback'	=> 'stortech_pro_is_masonry_product_product_section_content_product_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'stortech_pro_theme_options[masonry_product_content_category]', array(
	'sanitize_callback' => 'stortech_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Stortech_Pro_Dropdown_Taxonomy_Control( $wp_customize,'stortech_pro_theme_options[masonry_product_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'stortech-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'stortech-pro' ),
	'section'           => 'stortech_pro_masonry_product_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'stortech_pro_is_masonry_product_section_content_category_enable'
) ) );
