<?php
/**
 * Popular Posts Section options
 *
 * @package Theme Palace
 * @subpackage Stortech Pro
 * @since Stortech Pro 1.0.0
 */

// Add Popular Posts section
$wp_customize->add_section( 'stortech_pro_popular_blog_section', array(
	'title'             => esc_html__( 'Popular Posts','stortech-pro' ),
	'description'       => esc_html__( 'Popular Posts Section options.', 'stortech-pro' ),
	'panel'             => 'stortech_pro_front_page_panel',
	'active_callback'	=> 'stortech_pro_is_sixth_design_enable',
) );

// Popular Posts content enable control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[popular_blog_section_enable]', array(
	'default'			=> 	$options['popular_blog_section_enable'],
	'sanitize_callback' => 'stortech_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Stortech_Pro_Switch_Control( $wp_customize, 'stortech_pro_theme_options[popular_blog_section_enable]', array(
	'label'             => esc_html__( 'Popular Posts Section Enable', 'stortech-pro' ),
	'section'           => 'stortech_pro_popular_blog_section',
	'on_off_label' 		=> stortech_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'stortech_pro_theme_options[popular_blog_section_enable]', array(
		'selector'            => '#blog-popular-posts .tooltiptext',
		'settings'            => 'stortech_pro_theme_options[popular_blog_section_enable]',
    ) );
}


// popular_blog title setting and control
$wp_customize->add_setting( 'stortech_pro_theme_options[popular_blog_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['popular_blog_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[popular_blog_title]', array(
	'label'           	=> esc_html__( 'Title', 'stortech-pro' ),
	'section'        	=> 'stortech_pro_popular_blog_section',
	'active_callback' 	=> 'stortech_pro_is_popular_blog_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'stortech_pro_theme_options[popular_blog_title]', array(
		'selector'            => '#latest-posts .section-header h2',
		'settings'            => 'stortech_pro_theme_options[popular_blog_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'stortech_pro_popular_blog_title_partial',
    ) );
}

$wp_customize->add_setting( 'stortech_pro_theme_options[popular_blog_btn_label]', array(
		'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[popular_blog_btn_label]', array(
	'label'           	=> esc_html__( 'Popular Blog Button Lable', 'stortech-pro' ),
	'section'        	=> 'stortech_pro_popular_blog_section',
	'active_callback' 	=> 'stortech_pro_is_popular_blog_section_enable',
	'type'				=> 'text',
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[popular_blog_count]', array(
	'default'          	=> $options['popular_blog_count'],
	'sanitize_callback' => 'stortech_pro_sanitize_number_range',
	'validate_callback' => 'stortech_pro_validate_popular_blog_count',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[popular_blog_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'stortech-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'stortech-pro' ),
	'section'           => 'stortech_pro_popular_blog_section',
	'active_callback'   => 'stortech_pro_is_popular_blog_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Popular Posts content type control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[popular_blog_content_type]', array(
	'default'          	=> $options['popular_blog_content_type'],
	'sanitize_callback' => 'stortech_pro_sanitize_select',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[popular_blog_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'stortech-pro' ),
	'section'           => 'stortech_pro_popular_blog_section',
	'type'				=> 'select',
	'active_callback' 	=> 'stortech_pro_is_popular_blog_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'stortech-pro' ),
		'post' 		=> esc_html__( 'Post', 'stortech-pro' ),
		'category' 	=> esc_html__( 'Category', 'stortech-pro' ),
		'recent' 	=> esc_html__( 'Recent', 'stortech-pro' ),
	),
) );


for ( $i = 1; $i <= $options['popular_blog_count']; $i++ ) :
	// popular_blog pages drop down chooser control and setting
	$wp_customize->add_setting( 'stortech_pro_theme_options[popular_blog_content_page_' . $i . ']', array(
		'sanitize_callback' => 'stortech_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Stortech_Pro_Dropdown_Chooser( $wp_customize, 'stortech_pro_theme_options[popular_blog_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'stortech-pro' ), $i ),
		'section'           => 'stortech_pro_popular_blog_section',
		'choices'			=> stortech_pro_page_choices(),
		'active_callback'	=> 'stortech_pro_is_popular_blog_section_content_page_enable',
	) ) );

	// popular_blog posts drop down chooser control and setting
	$wp_customize->add_setting( 'stortech_pro_theme_options[popular_blog_content_post_' . $i . ']', array(
		'sanitize_callback' => 'stortech_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Stortech_Pro_Dropdown_Chooser( $wp_customize, 'stortech_pro_theme_options[popular_blog_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'stortech-pro' ), $i ),
		'section'           => 'stortech_pro_popular_blog_section',
		'choices'			=> stortech_pro_post_choices(),
		'active_callback'	=> 'stortech_pro_is_popular_blog_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'stortech_pro_theme_options[popular_blog_content_category]', array(
	'sanitize_callback' => 'stortech_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Stortech_Pro_Dropdown_Taxonomy_Control( $wp_customize,'stortech_pro_theme_options[popular_blog_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'stortech-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'stortech-pro' ),
	'section'           => 'stortech_pro_popular_blog_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'stortech_pro_is_popular_blog_section_content_category_enable'
) ) );
