<?php
/**
 * product_layout_features Section options
 *
 * @package Theme Palace
 * @subpackage Stortech Pro
 * @since Stortech Pro 1.0.0
 */

// Add product_layout_features section
$wp_customize->add_section( 'stortech_pro_product_layout_features_section', array(
	'title'             => esc_html__( 'Product Features','stortech-pro' ),
	'description'       => esc_html__( 'Product Features Section options.', 'stortech-pro' ),
	'panel'             => 'stortech_pro_front_page_panel',
	'active_callback'	=> 'stortech_pro_is_product_design_enable',
) );

// product_layout_features content enable control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[product_layout_features_section_enable]', array(
	'default'			=> 	$options['product_layout_features_section_enable'],
	'sanitize_callback' => 'stortech_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Stortech_Pro_Switch_Control( $wp_customize, 'stortech_pro_theme_options[product_layout_features_section_enable]', array(
	'label'             => esc_html__( 'Product Features Section Enable', 'stortech-pro' ),
	'section'           => 'stortech_pro_product_layout_features_section',
	'on_off_label' 		=> stortech_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'stortech_pro_theme_options[product_layout_features_section_enable]', array(
        'selector'            => '#services .tooltiptext',
        'settings'            => 'stortech_pro_theme_options[product_layout_features_section_enable]',
    ) );
}

// recent_product title setting and control
$wp_customize->add_setting( 'stortech_pro_theme_options[product_layout_features_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['product_layout_features_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[product_layout_features_title]', array(
	'label'           	=> esc_html__( 'Title', 'stortech-pro' ),
	'section'        	=> 'stortech_pro_product_layout_features_section',
	'active_callback' 	=> 'stortech_pro_is_product_layout_features_section_enable',
	'type'				=> 'text',
) );

// recent_product title setting and control
$wp_customize->add_setting( 'stortech_pro_theme_options[product_layout_features_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['product_layout_features_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[product_layout_features_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'stortech-pro' ),
	'section'        	=> 'stortech_pro_product_layout_features_section',
	'active_callback' 	=> 'stortech_pro_is_product_layout_features_section_enable',
	'type'				=> 'text',
) );

// layout_features image setting and control.
$wp_customize->add_setting( 'stortech_pro_theme_options[product_layout_features_image]', array(
	'sanitize_callback' => 'stortech_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'stortech_pro_theme_options[product_layout_features_image]',
		array(
		'label'       		=> esc_html__( 'Image', 'stortech-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'stortech-pro' ), 1920, 1280 ),
		'section'     		=> 'stortech_pro_product_layout_features_section',
		'active_callback'	=> 'stortech_pro_is_product_layout_features_section_enable',
) ) );

// product_layout_features content type control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[product_layout_features_column_layout]', array(
	'default'          	=> $options['product_layout_features_column_layout'],
	'sanitize_callback' => 'stortech_pro_sanitize_select',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[product_layout_features_column_layout]', array(
	'label'             => esc_html__( 'Column Layout', 'stortech-pro' ),
	'section'           => 'stortech_pro_product_layout_features_section',
	'type'				=> 'select',
	'active_callback' 	=> 'stortech_pro_is_product_layout_features_section_enable',
	'choices'			=> array( 
		'col-3' 		=> esc_html__( '3 Column', 'stortech-pro' ),
		'col-4' 		=> esc_html__( '4 Column', 'stortech-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[product_layout_features_count]', array(
	'default'          	=> $options['product_layout_features_count'],
	'sanitize_callback' => 'stortech_pro_sanitize_number_range',
	'validate_callback' => 'stortech_pro_validate_product_layout_features_count',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[product_layout_features_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'stortech-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'stortech-pro' ),
	'section'           => 'stortech_pro_product_layout_features_section',
	'active_callback'   => 'stortech_pro_is_product_layout_features_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// product_layout_features content type control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[product_layout_features_content_type]', array(
	'default'          	=> $options['product_layout_features_content_type'],
	'sanitize_callback' => 'stortech_pro_sanitize_select',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[product_layout_features_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'stortech-pro' ),
	'section'           => 'stortech_pro_product_layout_features_section',
	'type'				=> 'select',
	'active_callback' 	=> 'stortech_pro_is_product_layout_features_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'stortech-pro' ),
		'post' 		=> esc_html__( 'Post', 'stortech-pro' ),
		'category' 	=> esc_html__( 'Category', 'stortech-pro' ),
	),
) );

for ( $i = 1; $i <= $options['product_layout_features_count']; $i++ ) :
	// product_layout_features pages drop down chooser control and setting
	$wp_customize->add_setting( 'stortech_pro_theme_options[product_layout_features_content_page_' . $i . ']', array(
		'sanitize_callback' => 'stortech_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Stortech_Pro_Dropdown_Chooser( $wp_customize, 'stortech_pro_theme_options[product_layout_features_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'stortech-pro' ), $i ),
		'section'           => 'stortech_pro_product_layout_features_section',
		'choices'			=> stortech_pro_page_choices(),
		'active_callback'	=> 'stortech_pro_is_product_layout_features_section_content_page_enable',
	) ) );

	// product_layout_features posts drop down chooser control and setting
	$wp_customize->add_setting( 'stortech_pro_theme_options[product_layout_features_content_post_' . $i . ']', array(
		'sanitize_callback' => 'stortech_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Stortech_Pro_Dropdown_Chooser( $wp_customize, 'stortech_pro_theme_options[product_layout_features_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'stortech-pro' ), $i ),
		'section'           => 'stortech_pro_product_layout_features_section',
		'choices'			=> stortech_pro_post_choices(),
		'active_callback'	=> 'stortech_pro_is_product_layout_features_section_content_post_enable',
	) ) );

	$wp_customize->add_setting( 'stortech_pro_theme_options[product_layout_features_content_icon_' . $i . ']', array(
        'sanitize_callback' => 'sanitize_text_field',
    ) );

    $wp_customize->add_control( new Stortech_Pro_Icon_Picker( $wp_customize, 'stortech_pro_theme_options[product_layout_features_content_icon_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Icon %d', 'stortech-pro' ), $i ),
        'section'           => 'stortech_pro_product_layout_features_section',
        'active_callback'   => 'stortech_pro_is_product_layout_features_section_enable',
    ) ) );

    $wp_customize->add_setting( 'stortech_pro_theme_options[product_layout_features_hr_'. $i .']', array(
        'sanitize_callback' => 'sanitize_text_field'
    ) );

    $wp_customize->add_control( new Stortech_Pro_Customize_Horizontal_Line( $wp_customize, 'stortech_pro_theme_options[product_layout_features_hr_'. $i .']',
        array(
            'section'           => 'stortech_pro_product_layout_features_section',
            'active_callback'   => 'stortech_pro_is_product_layout_features_section_enable',
            'type'            => 'hr'
    ) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'stortech_pro_theme_options[product_layout_features_content_category]', array(
	'sanitize_callback' => 'stortech_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Stortech_Pro_Dropdown_Taxonomies_Control( $wp_customize,'stortech_pro_theme_options[product_layout_features_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'stortech-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'stortech-pro' ),
	'section'           => 'stortech_pro_product_layout_features_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'stortech_pro_is_product_layout_features_section_content_category_enable'
) ) );