<?php
/**
 * product_layout_similar_product Section options
 *
 * @package Theme Palace
 * @subpackage Stortech Pro
 * @since Stortech Pro 1.0.0
 */
if ( !class_exists('WooCommerce') ) {
	return;
}

if ( $options['home_layout'] !== 'product' ) {
	return;
}

// Add product_layout_similar_product section
$wp_customize->add_section( 'stortech_pro_product_layout_similar_product_section', array(
	'title'             => esc_html__( 'Similar Product Section','stortech-pro' ),
	'description'       => esc_html__( 'Similar Product Section Section options.', 'stortech-pro' ),
	'panel'             => 'stortech_pro_front_page_panel',
	'active_callback'	=> 'stortech_pro_is_product_design_enable',
) );

// product_layout_similar_product content enable control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[product_layout_similar_product_section_enable]', array(
	'default'			=> 	$options['product_layout_similar_product_section_enable'],
	'sanitize_callback' => 'stortech_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Stortech_Pro_Switch_Control( $wp_customize, 'stortech_pro_theme_options[product_layout_similar_product_section_enable]', array(
	'label'             => esc_html__( 'Recent product Section Enable', 'stortech-pro' ),
	'section'           => 'stortech_pro_product_layout_similar_product_section',
	'on_off_label' 		=> stortech_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'stortech_pro_theme_options[product_layout_similar_product_section_enable]', array(
        'selector'            => '#similar-product .tooltiptext',
        'settings'            => 'stortech_pro_theme_options[product_layout_similar_product_section_enable]',
    ) );
}




// product_layout_similar_product title setting and control
$wp_customize->add_setting( 'stortech_pro_theme_options[product_layout_similar_product_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['product_layout_similar_product_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[product_layout_similar_product_title]', array(
	'label'           	=> esc_html__( 'Title', 'stortech-pro' ),
	'section'        	=> 'stortech_pro_product_layout_similar_product_section',
	'active_callback' 	=> 'stortech_pro_is_product_layout_similar_product_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'stortech_pro_theme_options[product_layout_similar_product_title]', array(
		'selector'            => '#product_layout_similar-products .section-header h2',
		'settings'            => 'stortech_pro_theme_options[product_layout_similar_product_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'stortech_pro_product_layout_similar_product_title_partial',
    ) );
}


$wp_customize->add_setting( 'stortech_pro_theme_options[product_layout_similar_product_count]', array(
	'default'          	=> $options['product_layout_similar_product_count'],
	'sanitize_callback' => 'stortech_pro_sanitize_number_range',
	'validate_callback' => 'stortech_pro_validate_product_layout_similar_product_count',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[product_layout_similar_product_count]', array(
	'label'             => esc_html__( 'Number of Product', 'stortech-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'stortech-pro' ),
	'section'           => 'stortech_pro_product_layout_similar_product_section',
	'active_callback'   => 'stortech_pro_is_product_layout_similar_product_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

$wp_customize->add_setting( 'stortech_pro_theme_options[product_layout_similar_product_content_type]', array(
	'default'          	=> $options['product_layout_similar_product_content_type'],
	'sanitize_callback' => 'stortech_pro_sanitize_select',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[product_layout_similar_product_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'stortech-pro' ),
	'section'           => 'stortech_pro_product_layout_similar_product_section',
	'type'				=> 'select',
	'active_callback' 	=> 'stortech_pro_is_product_layout_similar_product_section_enable',
	'choices'			=> stortech_pro_product_layout_similar_product_options(),
) );

for( $i = 1 ; $i <= $options['product_layout_similar_product_count'] ; $i++ ){

	$wp_customize->add_setting( 'stortech_pro_theme_options[product_layout_similar_product_content_page_' . $i . ']', array(
		'sanitize_callback' => 'stortech_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Stortech_Pro_Dropdown_Chooser( $wp_customize, 'stortech_pro_theme_options[product_layout_similar_product_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Product %d', 'stortech-pro' ), $i ),
		'section'           => 'stortech_pro_product_layout_similar_product_section',
		'choices'			=> stortech_pro_product_choices(),
		'active_callback'	=> 'stortech_pro_is_product_layout_similar_product_section_content_product_enable',
	) ) );
}

$wp_customize->add_setting(  'stortech_pro_theme_options[product_layout_similar_product_category]', array(
		'sanitize_callback' => 'stortech_pro_sanitize_integers',
	) ) ;

$wp_customize->add_control( new Stortech_Pro_Dropdown_Taxonomies_Control( $wp_customize,'stortech_pro_theme_options[product_layout_similar_product_category]', array(
	'label'             => esc_html__( 'Select Product Categories', 'stortech-pro' ),
	'description'      	=> esc_html__( 'Note: Press CTRL and select multiple category. Latest four posts will be shown from each selected category', 'stortech-pro' ),
	'section'           => 'stortech_pro_product_layout_similar_product_section',
	'taxonomy'			=> class_exists('WooCommerce') ? 'product_cat' : 'category',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'stortech_pro_is_product_layout_similar_product_section_content_product_category_enable',
) ) );

$wp_customize->add_setting( 'stortech_pro_theme_options[product_layout_similar_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[product_layout_similar_btn_label]', array(
	'label'           	=>  esc_html__( 'Product Zoom Button Lable', 'stortech-pro' ),
	'section'        	=> 'stortech_pro_product_layout_similar_product_section',
	'active_callback' 	=> 'stortech_pro_is_product_layout_similar_product_section_enable',
	'type'				=> 'text',
) );

$wp_customize->add_setting( 'stortech_pro_theme_options[product_layout_similar_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[product_layout_similar_btn_url]', array(
	'label'           	=>  esc_html__( 'Product Zoom Button Link ', 'stortech-pro' ),
	'section'        	=> 'stortech_pro_product_layout_similar_product_section',
	'active_callback' 	=> 'stortech_pro_is_product_layout_similar_product_section_enable',
	'type'				=> 'url',
) );