<?php
/**
 * services Section options
 *
 * @package Theme Palace
 * @subpackage Stortech Pro
 * @since Stortech Pro 1.0.0
 */

// Add services section
$wp_customize->add_section( 'stortech_pro_services_section', array(
	'title'             => esc_html__( 'Services','stortech-pro' ),
	'description'       => esc_html__( 'Services Section options.', 'stortech-pro' ),
	'panel'             => 'stortech_pro_front_page_panel',
	'active_callback'	=> 'stortech_pro_is_services_design_enable',
) );

// services content enable control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[services_section_enable]', array(
	'default'			=> 	$options['services_section_enable'],
	'sanitize_callback' => 'stortech_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Stortech_Pro_Switch_Control( $wp_customize, 'stortech_pro_theme_options[services_section_enable]', array(
	'label'             => esc_html__( 'Services Section Enable', 'stortech-pro' ),
	'section'           => 'stortech_pro_services_section',
	'on_off_label' 		=> stortech_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'stortech_pro_theme_options[services_section_enable]', array(
        'selector'            => '#our-services .tooltiptext',
        'settings'            => 'stortech_pro_theme_options[services_section_enable]',
    ) );
}

// services content type control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[services_column_layout]', array(
	'default'          	=> $options['services_column_layout'],
	'sanitize_callback' => 'stortech_pro_sanitize_select',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[services_column_layout]', array(
	'label'             => esc_html__( 'Column Layout', 'stortech-pro' ),
	'section'           => 'stortech_pro_services_section',
	'type'				=> 'select',
	'active_callback' 	=> 'stortech_pro_is_services_section_enable',
	'choices'			=> array( 
		'col-3' 		=> esc_html__( '3 Column', 'stortech-pro' ),
		'col-4' 		=> esc_html__( '4 Column', 'stortech-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[services_count]', array(
	'default'          	=> $options['services_count'],
	'sanitize_callback' => 'stortech_pro_sanitize_number_range',
	'validate_callback' => 'stortech_pro_validate_services_count',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[services_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'stortech-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'stortech-pro' ),
	'section'           => 'stortech_pro_services_section',
	'active_callback'   => 'stortech_pro_is_services_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// services content type control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[services_content_type]', array(
	'default'          	=> $options['services_content_type'],
	'sanitize_callback' => 'stortech_pro_sanitize_select',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[services_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'stortech-pro' ),
	'section'           => 'stortech_pro_services_section',
	'type'				=> 'select',
	'active_callback' 	=> 'stortech_pro_is_services_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'stortech-pro' ),
		'post' 		=> esc_html__( 'Post', 'stortech-pro' ),
		'category' 	=> esc_html__( 'Category', 'stortech-pro' ),
	),
) );

for ( $i = 1; $i <= $options['services_count']; $i++ ) :
	// services pages drop down chooser control and setting
	$wp_customize->add_setting( 'stortech_pro_theme_options[services_content_page_' . $i . ']', array(
		'sanitize_callback' => 'stortech_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Stortech_Pro_Dropdown_Chooser( $wp_customize, 'stortech_pro_theme_options[services_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'stortech-pro' ), $i ),
		'section'           => 'stortech_pro_services_section',
		'choices'			=> stortech_pro_page_choices(),
		'active_callback'	=> 'stortech_pro_is_services_section_content_page_enable',
	) ) );

	// services posts drop down chooser control and setting
	$wp_customize->add_setting( 'stortech_pro_theme_options[services_content_post_' . $i . ']', array(
		'sanitize_callback' => 'stortech_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Stortech_Pro_Dropdown_Chooser( $wp_customize, 'stortech_pro_theme_options[services_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'stortech-pro' ), $i ),
		'section'           => 'stortech_pro_services_section',
		'choices'			=> stortech_pro_post_choices(),
		'active_callback'	=> 'stortech_pro_is_services_section_content_post_enable',
	) ) );

	$wp_customize->add_setting( 'stortech_pro_theme_options[services_content_icon_' . $i . ']', array(
        'sanitize_callback' => 'sanitize_text_field',
    ) );

    $wp_customize->add_control( new Stortech_Pro_Icon_Picker( $wp_customize, 'stortech_pro_theme_options[services_content_icon_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Icon %d', 'stortech-pro' ), $i ),
        'section'           => 'stortech_pro_services_section',
        'active_callback'   => 'stortech_pro_is_services_section_enable',
    ) ) );

    $wp_customize->add_setting( 'stortech_pro_theme_options[services_hr_'. $i .']', array(
        'sanitize_callback' => 'sanitize_text_field'
    ) );

    $wp_customize->add_control( new Stortech_Pro_Customize_Horizontal_Line( $wp_customize, 'stortech_pro_theme_options[services_hr_'. $i .']',
        array(
            'section'           => 'stortech_pro_services_section',
            'active_callback'   => 'stortech_pro_is_services_section_enable',
            'type'            => 'hr'
    ) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'stortech_pro_theme_options[services_content_category]', array(
	'sanitize_callback' => 'stortech_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Stortech_Pro_Dropdown_Taxonomies_Control( $wp_customize,'stortech_pro_theme_options[services_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'stortech-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'stortech-pro' ),
	'section'           => 'stortech_pro_services_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'stortech_pro_is_services_section_content_category_enable'
) ) );