<?php
/**
 * Product Short Description Section options
 *
 * @package Theme Palace
 * @subpackage Stortech Pro
 * @since Stortech Pro 1.0.0
 */

// Add Product Short Description section
$wp_customize->add_section( 'stortech_pro_product_layout_short_des_section', array(
	'title'             => esc_html__( 'Product Short Description','stortech-pro' ),
	'description'       => esc_html__( 'Product Short Description Section options.', 'stortech-pro' ),
	'panel'             => 'stortech_pro_front_page_panel',
	'active_callback'	=> 'stortech_pro_is_product_design_enable',
) );

// Product Short Description content enable control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[product_layout_short_des_section_enable]', array(
	'default'			=> 	$options['product_layout_short_des_section_enable'],
	'sanitize_callback' => 'stortech_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Stortech_Pro_Switch_Control( $wp_customize, 'stortech_pro_theme_options[product_layout_short_des_section_enable]', array(
	'label'             => esc_html__( 'Product Short Description Section Enable', 'stortech-pro' ),
	'section'           => 'stortech_pro_product_layout_short_des_section',
	'on_off_label' 		=> stortech_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'stortech_pro_theme_options[product_layout_short_des_section_enable]', array(
        'selector'            => '#gallery .tooltiptext',
        'settings'            => 'stortech_pro_theme_options[product_layout_short_des_section_enable]',
    ) );
}


// Product Stort Description content type control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[product_layout_short_des_content_type]', array(
	'default'          	=> $options['product_layout_short_des_content_type'],
	'sanitize_callback' => 'stortech_pro_sanitize_select',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[product_layout_short_des_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'stortech-pro' ),
	'section'           => 'stortech_pro_product_layout_short_des_section',
	'type'				=> 'select',
	'active_callback' 	=> 'stortech_pro_is_product_layout_short_des_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'stortech-pro' ),
		'post' 		=> esc_html__( 'Post', 'stortech-pro' ),
		'custom' 		=> esc_html__( 'Custom', 'stortech-pro' ),
	),
) );


// product_layout_short_des pages drop down chooser control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[product_layout_short_des_content_page]', array(
	'sanitize_callback' => 'stortech_pro_sanitize_page',
) );

$wp_customize->add_control( new Stortech_Pro_Dropdown_Chooser( $wp_customize, 'stortech_pro_theme_options[product_layout_short_des_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'stortech-pro' ), 
	'section'           => 'stortech_pro_product_layout_short_des_section',
	'choices'			=> stortech_pro_page_choices(),
	'active_callback'	=> 'stortech_pro_is_product_layout_short_des_section_content_page_enable',
) ) );

// product_layout_short_des posts drop down chooser control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[product_layout_short_des_content_post]', array(
	'sanitize_callback' => 'stortech_pro_sanitize_page',
) );

$wp_customize->add_control( new Stortech_Pro_Dropdown_Chooser( $wp_customize, 'stortech_pro_theme_options[product_layout_short_des_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'stortech-pro' ), 
	'section'           => 'stortech_pro_product_layout_short_des_section',
	'choices'			=> stortech_pro_post_choices(),
	'active_callback'	=> 'stortech_pro_is_product_layout_short_des_section_content_post_enable',
) ) ); 

$wp_customize->add_setting( 'stortech_pro_theme_options[product_layout_short_des_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[product_layout_short_des_btn_label]', array(
	'label'           	=>  esc_html__( 'Product Stort Description Button Lable', 'stortech-pro' ),
	'section'        	=> 'stortech_pro_product_layout_short_des_section',
	'active_callback' 	=> 'stortech_pro_is_product_layout_short_des_section_enable',
	'type'				=> 'text',
) );

$wp_customize->add_setting( 'stortech_pro_theme_options[product_layout_short_des_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[product_layout_short_des_btn_url]', array(
	'label'           	=>  esc_html__( 'Product Stort Description Button Link ', 'stortech-pro' ),
	'section'        	=> 'stortech_pro_product_layout_short_des_section',
	'active_callback' 	=> 'stortech_pro_is_product_layout_short_des_section_enable',
	'type'				=> 'url',
) );

// layout_short_des title setting and control
$wp_customize->add_setting( 'stortech_pro_theme_options[product_layout_short_des_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['product_layout_short_des_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[product_layout_short_des_title]', array(
	'label'           	=> esc_html__( 'Title', 'stortech-pro' ),
	'section'        	=> 'stortech_pro_product_layout_short_des_section',
	'active_callback' 	=> 'stortech_pro_is_product_layout_short_des_section_content_custom_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'stortech_pro_theme_options[product_layout_short_des_title]', array(
		'selector'            => '#gallery .entry-container .section-header h2.section-title',
		'settings'            => 'stortech_pro_theme_options[product_layout_short_des_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'stortech_pro_product_layout_short_des_title_partial',
    ) );
}

// layout_short_des description setting and control
$wp_customize->add_setting( 'stortech_pro_theme_options[product_layout_short_des_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['product_layout_short_des_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[product_layout_short_des_description]', array(
	'label'           	=> esc_html__( 'Description', 'stortech-pro' ),
	'section'        	=> 'stortech_pro_product_layout_short_des_section',
	'active_callback' 	=> 'stortech_pro_is_product_layout_short_des_section_content_custom_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'stortech_pro_theme_options[product_layout_short_des_description]', array(
		'selector'            => '#gallery .entry-container .entry-content',
		'settings'            => 'stortech_pro_theme_options[product_layout_short_des_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'stortech_pro_product_layout_short_des_description_partial',
    ) );
}

// layout_short_des image setting and control.
$wp_customize->add_setting( 'stortech_pro_theme_options[product_layout_short_des_image]', array(
	'sanitize_callback' => 'stortech_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'stortech_pro_theme_options[product_layout_short_des_image]',
		array(
		'label'       		=> esc_html__( 'Image', 'stortech-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'stortech-pro' ), 1920, 1280 ),
		'section'     		=> 'stortech_pro_product_layout_short_des_section',
		'active_callback'	=> 'stortech_pro_is_product_layout_short_des_section_content_custom_enable',
) ) );
