<?php
/**
 * Slider Section options
 *
 * @package Theme Palace
 * @subpackage Travel Master Pro
 * @since Travel Master Pro 1.0.0
 */

// Add Slider section
$wp_customize->add_section( 'stortech_pro_slider_section', array(
	'title'             => esc_html__( 'Main Slider','stortech-pro' ),
	'description'       => esc_html__( 'Slider Section options.', 'stortech-pro' ),
	'panel'             => 'stortech_pro_front_page_panel',
	'active_callback'	=> 'stortech_pro_is_slider_design_enable',
) );

// Slider content enable control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[slider_section_enable]', array(
	'default'			=> 	$options['slider_section_enable'],
	'sanitize_callback' => 'stortech_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Stortech_Pro_Switch_Control( $wp_customize, 'stortech_pro_theme_options[slider_section_enable]', array(
	'label'             => esc_html__( 'Slider Section Enable', 'stortech-pro' ),
	'section'           => 'stortech_pro_slider_section',
	'on_off_label' 		=> stortech_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'stortech_pro_theme_options[slider_section_enable]', array(
        'selector'            => '#featured-slider .tooltiptext',
        'settings'            => 'stortech_pro_theme_options[slider_section_enable]',
    ) );
}

// Slider content enable control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[slider_autoplay]', array(
	'default'			=> 	$options['slider_autoplay'],
	'sanitize_callback' => 'stortech_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Stortech_Pro_Switch_Control( $wp_customize, 'stortech_pro_theme_options[slider_autoplay]', array(
	'label'             => esc_html__( 'Auto Play Enable', 'stortech-pro' ),
	'section'           => 'stortech_pro_slider_section',
	'on_off_label' 		=> stortech_pro_switch_options(),
	'active_callback' 	=> 'stortech_pro_is_slider_section_enable',
) ) );

$wp_customize->add_setting( 'stortech_pro_theme_options[slider_subtitle]', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> $options['slider_subtitle'],
) );

$wp_customize->add_control( 'stortech_pro_theme_options[slider_subtitle]', array(
	'label'           	=> esc_html__( 'Slider Subtitle', 'stortech-pro' ),
	'section'        	=> 'stortech_pro_slider_section',
	'active_callback' 	=> 'stortech_pro_is_slider_subtitle_enable',
	'type'				=> 'text',
) );

$wp_customize->add_setting( 'stortech_pro_theme_options[slider_btn_label]', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> $options['slider_btn_label'],
) );

$wp_customize->add_control( 'stortech_pro_theme_options[slider_btn_label]', array(
	'label'           	=> esc_html__( 'Slider Button Label', 'stortech-pro' ),
	'section'        	=> 'stortech_pro_slider_section',
	'active_callback' 	=> 'stortech_pro_is_slider_section_enable',
	'type'				=> 'text',
) );


// Event social icons number control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[slider_count]', array(
	'default'          	=> $options['slider_count'],
	'sanitize_callback' => 'stortech_pro_sanitize_number_range',
	'validate_callback' => 'stortech_pro_validate_slider_count',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[slider_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'stortech-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'stortech-pro' ),
	'section'           => 'stortech_pro_slider_section',
	'active_callback'   => 'stortech_pro_is_slider_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );
if ($options['home_layout'] == 'first-design') {

	for( $i=1 ; $i<= $options['slider_count'] ; $i++ ) {

		$wp_customize->add_setting( 'stortech_pro_theme_options[slider_alt_btn_label_'.$i.']', array(
			'sanitize_callback' => 'sanitize_text_field',
		) );

		$wp_customize->add_control( 'stortech_pro_theme_options[slider_alt_btn_label_'.$i.']', array(
			'label'           	=> sprintf( esc_html__( 'Slider Alternative Button Label', 'stortech-pro' ), $i ),
			'section'        	=> 'stortech_pro_slider_section',
			'active_callback' 	=> 'stortech_pro_is_slider_section_enable',
			'type'				=> 'text',
		) );

		$wp_customize->add_setting( 'stortech_pro_theme_options[slider_btn_url_'.$i.']', array(
			'sanitize_callback' => 'esc_url_raw',
		) );

		$wp_customize->add_control( 'stortech_pro_theme_options[slider_btn_url_'.$i.']', array(
			'label'           	=> sprintf( esc_html__( 'Slider Button Link %d', 'stortech-pro' ), $i ),
			'section'        	=> 'stortech_pro_slider_section',
			'active_callback' 	=> 'stortech_pro_is_slider_section_enable',
			'type'				=> 'url',
		) );
	}
}

$wp_customize->add_setting( 'stortech_pro_theme_options[slider_hr_2]', array(
	'sanitize_callback' => 'sanitize_text_field'

) );

$wp_customize->add_control( new Stortech_Pro_Customize_Horizontal_Line( $wp_customize, 'stortech_pro_theme_options[slider_hr_2]',
	array(
		'section'         => 'stortech_pro_slider_section',
		'active_callback' => 'stortech_pro_is_slider_section_enable',
		'type'			  => 'hr'
) ) );

// Slider content type control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[slider_content_type]', array(
	'default'          	=> $options['slider_content_type'],
	'sanitize_callback' => 'stortech_pro_sanitize_select',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[slider_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'stortech-pro' ),
	'section'           => 'stortech_pro_slider_section',
	'type'				=> 'select',
	'active_callback' 	=> 'stortech_pro_is_slider_section_enable',
	'choices'			=> stortech_pro_slider_product_content_type(),
) );

for ( $i = 1; $i <= $options['slider_count']; $i++ ) :
	// slider pages drop down chooser control and setting
	$wp_customize->add_setting( 'stortech_pro_theme_options[slider_content_page_' . $i . ']', array(
		'sanitize_callback' => 'stortech_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Stortech_Pro_Dropdown_Chooser( $wp_customize, 'stortech_pro_theme_options[slider_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'stortech-pro' ), $i ),
		'section'           => 'stortech_pro_slider_section',
		'choices'			=> stortech_pro_page_choices(),
		'active_callback'	=> 'stortech_pro_is_slider_section_content_page_enable',
	) ) );

	// slider posts drop down chooser control and setting
	$wp_customize->add_setting( 'stortech_pro_theme_options[slider_content_post_' . $i . ']', array(
		'sanitize_callback' => 'stortech_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Stortech_Pro_Dropdown_Chooser( $wp_customize, 'stortech_pro_theme_options[slider_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'stortech-pro' ), $i ),
		'section'           => 'stortech_pro_slider_section',
		'choices'			=> stortech_pro_post_choices(),
		'active_callback'	=> 'stortech_pro_is_slider_section_content_post_enable',
	) ) ); 

	$wp_customize->add_setting( 'stortech_pro_theme_options[slider_product_content_page_' . $i . ']', array(
		'sanitize_callback' => 'stortech_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Stortech_Pro_Dropdown_Chooser( $wp_customize, 'stortech_pro_theme_options[slider_product_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Product %d', 'stortech-pro' ), $i ),
		'section'           => 'stortech_pro_slider_section',
		'choices'			=> stortech_pro_product_choices(),
		'active_callback'	=> 'stortech_pro_is_slider_product_section_content_product_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'stortech_pro_theme_options[slider_content_category]', array(
	'sanitize_callback' => 'stortech_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Stortech_Pro_Dropdown_Taxonomy_Control( $wp_customize,'stortech_pro_theme_options[slider_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'stortech-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'stortech-pro' ),
	'section'           => 'stortech_pro_slider_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'stortech_pro_is_slider_section_content_category_enable'
) ) );

if ($options['home_layout']!= 'third-design') {

	// stortech title setting and control
	$wp_customize->add_setting( 'stortech_pro_theme_options[slider_product_text]', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'stortech_pro_theme_options[slider_product_text]', array(
		'label'           	=> esc_html__( 'Product Text', 'stortech-pro' ),
		'section'        	=> 'stortech_pro_slider_section',
		'active_callback' 	=> 'stortech_pro_is_slider_product_section_content_product_enable',
		'type'				=> 'text',
	) );
}