<?php
/**
 * Team Section options
 *
 * @package Theme Palace
 * @subpackage Stortech Pro
 * @since Stortech Pro 1.0.0
 */

// Add Team section
$wp_customize->add_section( 'stortech_pro_team_section', array(
	'title'             => esc_html__( 'Teams','stortech-pro' ),
	'description'       => esc_html__( 'Teams Section options.', 'stortech-pro' ),
	'panel'             => 'stortech_pro_front_page_panel',
	'active_callback'	=> 'stortech_pro_is_fifth_design_enable',
) );

// Team content enable control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[team_section_enable]', array(
	'default'			=> 	$options['team_section_enable'],
	'sanitize_callback' => 'stortech_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Stortech_Pro_Switch_Control( $wp_customize, 'stortech_pro_theme_options[team_section_enable]', array(
	'label'             => esc_html__( 'Team Section Enable', 'stortech-pro' ),
	'section'           => 'stortech_pro_team_section',
	'on_off_label' 		=> stortech_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'stortech_pro_theme_options[team_section_enable]', array(
        'selector'            => '#business-team .wrapper',
        'settings'            => 'stortech_pro_theme_options[team_section_enable]',
    ) );
}

// team title setting and control
$wp_customize->add_setting( 'stortech_pro_theme_options[team_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['team_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[team_title]', array(
	'label'           	=> esc_html__( 'Title', 'stortech-pro' ),
	'section'        	=> 'stortech_pro_team_section',
	'active_callback' 	=> 'stortech_pro_is_team_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'stortech_pro_theme_options[team_title]', array(
		'selector'            => '#our-team h2.section-title',
		'settings'            => 'stortech_pro_theme_options[team_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'stortech_pro_team_title_partial',
    ) );
}
// Team content type control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[team_content_type]', array(
	'default'          	=> $options['team_content_type'],
	'sanitize_callback' => 'stortech_pro_sanitize_select',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[team_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'stortech-pro' ),
	'section'           => 'stortech_pro_team_section',
	'type'				=> 'select',
	'active_callback' 	=> 'stortech_pro_is_team_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'stortech-pro' ),
		'post' 		=> esc_html__( 'Post', 'stortech-pro' ),
		'category' 	=> esc_html__( 'Category', 'stortech-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'stortech-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[team_count]', array(
	'default'          	=> $options['team_count'],
	'sanitize_callback' => 'stortech_pro_sanitize_number_range',
	'validate_callback' => 'stortech_pro_validate_team_count',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[team_count]', array(
	'label'             => esc_html__( 'Number of Teams', 'stortech-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'stortech-pro' ),
	'section'           => 'stortech_pro_team_section',
	'active_callback'   => 'stortech_pro_is_team_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['team_count']; $i++ ) :

	// team pages drop down chooser control and setting
	$wp_customize->add_setting( 'stortech_pro_theme_options[team_content_page_' . $i . ']', array(
		'sanitize_callback' => 'stortech_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Stortech_Pro_Dropdown_Chooser( $wp_customize, 'stortech_pro_theme_options[team_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'stortech-pro' ), $i ),
		'section'           => 'stortech_pro_team_section',
		'choices'			=> stortech_pro_page_choices(),
		'active_callback'	=> 'stortech_pro_is_team_section_content_page_enable',
	) ) );

	// team posts drop down chooser control and setting
	$wp_customize->add_setting( 'stortech_pro_theme_options[team_content_post_' . $i . ']', array(
		'sanitize_callback' => 'stortech_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Stortech_Pro_Dropdown_Chooser( $wp_customize, 'stortech_pro_theme_options[team_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'stortech-pro' ), $i ),
		'section'           => 'stortech_pro_team_section',
		'choices'			=> stortech_pro_post_choices(),
		'active_callback'	=> 'stortech_pro_is_team_section_content_post_enable',
	) ) );


	// team image
	$wp_customize->add_setting( 'stortech_pro_theme_options[team_content_custom_image_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'stortech_pro_theme_options[team_content_custom_image_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Image %d', 'stortech-pro' ), $i ),
		'section'           => 'stortech_pro_team_section',
		'active_callback'   => 'stortech_pro_is_team_section_content_custom_enable',
	) ) );

	// team custom title
	$wp_customize->add_setting( 'stortech_pro_theme_options[team_content_custom_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'stortech_pro_theme_options[team_content_custom_title_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Title %d', 'stortech-pro' ), $i ),
		'section'           => 'stortech_pro_team_section',
		'active_callback'	=> 'stortech_pro_is_team_section_content_custom_enable',
	) );

	// team custom content
	$wp_customize->add_setting( 'stortech_pro_theme_options[team_content_custom_position_' . $i . ']', array(
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( 'stortech_pro_theme_options[team_content_custom_position_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Position %d', 'stortech-pro' ), $i ),
		'section'           => 'stortech_pro_team_section',
		'active_callback'	=> 'stortech_pro_is_team_section_enable',
	) );

	// team social
	$wp_customize->add_setting( 'stortech_pro_theme_options[team_social_' . $i. ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new Stortech_Pro_Multi_Input_Custom_Control( $wp_customize, 'stortech_pro_theme_options[team_social_' . $i. ']', array(
		'label'             => esc_html__( 'Social ', 'stortech-pro' ),
		'button_text'       => esc_html__( 'Add social.', 'stortech-pro' ),
		'section'           => 'stortech_pro_team_section',
		'active_callback' 	=> 'stortech_pro_is_team_section_enable',
	) ) );

	// Separator setting
	$wp_customize->add_setting( 'stortech_pro_theme_options[team_separator_' . $i . ']', array(
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( new Stortech_Pro_Note_Control( $wp_customize, 'stortech_pro_theme_options[team_separator_' . $i . ']', array(
		'section'           => 'stortech_pro_team_section',
		'active_callback'	=> 'stortech_pro_is_team_section_enable',
		'type'				=> 'custom-html',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'stortech_pro_theme_options[team_content_category]', array(
	'sanitize_callback' => 'stortech_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Stortech_Pro_Dropdown_Taxonomy_Control( $wp_customize,'stortech_pro_theme_options[team_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'stortech-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'stortech-pro' ),
	'section'           => 'stortech_pro_team_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'stortech_pro_is_team_section_content_category_enable'
) ) );

