<?php
/**
 * Testimonial Section options
 *
 * @package Theme Palace
 * @subpackage Stortech Pro
 * @since Stortech Pro 1.0.0
 */

// Add Testimonial section
$wp_customize->add_section( 'stortech_pro_testimonial_section', array(
	'title'             => esc_html__( 'Testimonial','stortech-pro' ),
	'description'       => esc_html__( 'Testimonial Section options.', 'stortech-pro' ),
	'panel'             => 'stortech_pro_front_page_panel',
	'active_callback'	=> 'stortech_pro_is_first_design_enable',
) );

// Testimonial content enable control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[testimonial_section_enable]', array(
	'default'			=> 	$options['testimonial_section_enable'],
	'sanitize_callback' => 'stortech_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Stortech_Pro_Switch_Control( $wp_customize, 'stortech_pro_theme_options[testimonial_section_enable]', array(
	'label'             => esc_html__( 'Testimonial Section Enable', 'stortech-pro' ),
	'section'           => 'stortech_pro_testimonial_section',
	'on_off_label' 		=> stortech_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'stortech_pro_theme_options[testimonial_section_enable]', array(
        'selector'            => '#testimonials .wrapper',
        'settings'            => 'stortech_pro_theme_options[testimonial_section_enable]',
    ) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[testimonial_count]', array(
	'default'          	=> $options['testimonial_count'],
	'sanitize_callback' => 'stortech_pro_sanitize_number_range',
	'validate_callback' => 'stortech_pro_validate_testimonial_count',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[testimonial_count]', array(
	'label'             => esc_html__( 'Number of Testimonials', 'stortech-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'stortech-pro' ),
	'section'           => 'stortech_pro_testimonial_section',
	'active_callback'   => 'stortech_pro_is_testimonial_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Testimonial content type control and setting
$wp_customize->add_setting( 'stortech_pro_theme_options[testimonial_content_type]', array(
	'default'          	=> $options['testimonial_content_type'],
	'sanitize_callback' => 'stortech_pro_sanitize_select',
) );

$wp_customize->add_control( 'stortech_pro_theme_options[testimonial_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'stortech-pro' ),
	'section'           => 'stortech_pro_testimonial_section',
	'type'				=> 'select',
	'active_callback' 	=> 'stortech_pro_is_testimonial_section_enable',
	'choices'			=> stortech_pro_testimonial_content_type(),
) );



for ( $i = 1; $i <= $options['testimonial_count']; $i++ ) :
	// testimonial pages drop down chooser control and setting
	$wp_customize->add_setting( 'stortech_pro_theme_options[testimonial_content_page_' . $i . ']', array(
		'sanitize_callback' => 'stortech_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Stortech_Pro_Dropdown_Chooser( $wp_customize, 'stortech_pro_theme_options[testimonial_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'stortech-pro' ), $i ),
		'section'           => 'stortech_pro_testimonial_section',
		'choices'			=> stortech_pro_page_choices(),
		'active_callback'	=> 'stortech_pro_is_testimonial_section_content_page_enable',
	) ) );


	// testimonial posts drop down chooser control and setting
	$wp_customize->add_setting( 'stortech_pro_theme_options[testimonial_content_post_' . $i . ']', array(
		'sanitize_callback' => 'stortech_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Stortech_Pro_Dropdown_Chooser( $wp_customize, 'stortech_pro_theme_options[testimonial_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'stortech-pro' ), $i ),
		'section'           => 'stortech_pro_testimonial_section',
		'choices'			=> stortech_pro_post_choices(),
		'active_callback'	=> 'stortech_pro_is_testimonial_section_content_post_enable',
	) ) );

	// testimonial title setting and control
	$wp_customize->add_setting( 'stortech_pro_theme_options[testimonial_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'stortech_pro_theme_options[testimonial_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Title %d', 'stortech-pro' ), $i ),
		'section'        	=> 'stortech_pro_testimonial_section',
		'active_callback' 	=> 'stortech_pro_is_testimonial_section_content_custom_enable',
		'type'				=> 'text',
	) );


	$options['testimonial_position_'.$i] = isset($options['testimonial_position_'.$i]) ? $options['testimonial_position_'.$i] : esc_html__('Happy Client', 'stortech-pro');
	// testimonial position setting and control
	$wp_customize->add_setting( 'stortech_pro_theme_options[testimonial_position_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> $options['testimonial_position_'.$i],
	) );

	$wp_customize->add_control( 'stortech_pro_theme_options[testimonial_position_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'position %d', 'stortech-pro' ), $i ),
		'section'        	=> 'stortech_pro_testimonial_section',
		'active_callback' 	=> 'stortech_pro_is_testimonial_section_content_position_enable',
		'type'				=> 'text',
	) );

	// testimonial description setting and control
	$wp_customize->add_setting( 'stortech_pro_theme_options[testimonial_description_' . $i . ']', array(
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( 'stortech_pro_theme_options[testimonial_description_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Description %d', 'stortech-pro' ), $i ),
		'section'        	=> 'stortech_pro_testimonial_section',
		'active_callback' 	=> 'stortech_pro_is_testimonial_section_content_custom_enable',
		'type'				=> 'textarea',
	) );

	// testimonial image setting and control.
	$wp_customize->add_setting( 'stortech_pro_theme_options[testimonial_image_' . $i . ']', array(
		'sanitize_callback' => 'stortech_pro_sanitize_image'
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'stortech_pro_theme_options[testimonial_image_' . $i . ']',
			array(
			'label'       		=> sprintf( esc_html__( 'Image %d', 'stortech-pro' ), $i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'stortech-pro' ), 200, 200 ),
			'section'     		=> 'stortech_pro_testimonial_section',
			'active_callback'	=> 'stortech_pro_is_testimonial_section_content_custom_enable',
	) ) );

	// testimonial position setting and control
	$wp_customize->add_setting( 'stortech_pro_theme_options[testimonial_link_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'stortech_pro_theme_options[testimonial_link_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'URL Link %d', 'stortech-pro' ), $i ),
		'section'        	=> 'stortech_pro_testimonial_section',
		'active_callback' 	=> 'stortech_pro_is_testimonial_section_content_custom_enable',
		'type'				=> 'url',
	) );

	// testimonial hr setting and control
	$wp_customize->add_setting( 'stortech_pro_theme_options[testimonial_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Stortech_Pro_Customize_Horizontal_Line( $wp_customize, 'stortech_pro_theme_options[testimonial_hr_'. $i .']',
		array(
			'section'         => 'stortech_pro_testimonial_section',
			'active_callback' => 'stortech_pro_is_testimonial_section_content_seperator_enable',
			'type'			  => 'hr'
	) ) );
endfor;