<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Stortech Pro
 * @since Stortech Pro 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */

function stortech_pro_product_choices() {
    $full_product_list = array();
    $product_id = array();
    $loop = new WP_Query(array('post_type' => array('product', 'product_variation'), 'posts_per_page' => -1));
    while ($loop->have_posts()) : $loop->the_post();
        $product_id[] = get_the_id();
    endwhile;
    wp_reset_postdata();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'stortech-pro' );
    foreach ( $product_id  as $id ) {
        $choices[ $id ] = get_the_title( $id );
    }
    return  $choices;
}

function stortech_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'stortech-pro' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function stortech_pro_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'stortech-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}



if ( ! function_exists( 'stortech_pro_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function stortech_pro_typography_options(){
        $font_family_arr = array();
        $font_family_arr[''] = esc_html__( '--Default--', 'stortech-pro' );

        // Make the request
        $request = wp_remote_get( get_theme_file_uri( 'assets/webfonts.json' ) );

        if( is_wp_error( $request ) ) {
            return false; // Bail early
        }
        // Retrieve the data
        $body = wp_remote_retrieve_body( $request );
        $data = json_decode( $body );
        if ( ! empty( $data ) ) {
            foreach ( $data->items as $items => $fonts ) {
                $family_str_arr = explode( ' ', $fonts->family );
                $family_value = implode( '+', $family_str_arr );
                $font_family_arr[ $family_value ] = $fonts->family;
            }
        }

        return $font_family_arr;
    }
endif;


if ( ! function_exists( 'stortech_pro_body_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function stortech_pro_body_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'stortech-pro' ),
            'body-font-1'     => esc_html__( 'News Cycle', 'stortech-pro' ),
            'body-font-2'     => esc_html__( 'Pontano Sans', 'stortech-pro' ),
            'body-font-3'     => esc_html__( 'Gudea', 'stortech-pro' ),
            'body-font-4'     => esc_html__( 'Quattrocento', 'stortech-pro' ),
            'body-font-5'     => esc_html__( 'Khand', 'stortech-pro' ),
        );

        $output = apply_filters( 'stortech_pro_body_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'stortech_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function stortech_pro_selected_sidebar() {
        $stortech_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'stortech-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'stortech-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'stortech-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'stortech-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'stortech-pro' ),
        );

        $output = apply_filters( 'stortech_pro_selected_sidebar', $stortech_pro_selected_sidebar );

        return $output;
    }
endif;

if ( ! function_exists( 'stortech_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function stortech_pro_site_layout() {
        $stortech_pro_site_layout = array(
            'wide-layout'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout' => get_template_directory_uri() . '/assets/images/boxed.png',
            'frame-layout' => get_template_directory_uri() . '/assets/images/framed.png',
        );

        $output = apply_filters( 'stortech_pro_site_layout', $stortech_pro_site_layout );
        return $output;
    }
endif;


if ( ! function_exists( 'stortech_pro_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function stortech_pro_global_sidebar_position() {
        $stortech_pro_global_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'stortech_pro_global_sidebar_position', $stortech_pro_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'stortech_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function stortech_pro_sidebar_position() {
        $stortech_pro_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
            'no-sidebar-content'   => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'stortech_pro_sidebar_position', $stortech_pro_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'stortech_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function stortech_pro_pagination_options() {
        $stortech_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'stortech-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'stortech-pro' ),
            'infinite'  => esc_html__( 'Infinite', 'stortech-pro' ),
        );

        $output = apply_filters( 'stortech_pro_pagination_options', $stortech_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'stortech_pro_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function stortech_pro_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'stortech-pro' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'stortech-pro' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'stortech-pro' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'stortech-pro' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'stortech-pro' ),
            'spinner-dots'          => esc_html__( 'Dots', 'stortech-pro' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'stortech-pro' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'stortech-pro' ),
        );
        return apply_filters( 'stortech_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'stortech_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function stortech_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'stortech-pro' ),
            'off'       => esc_html__( 'Disable', 'stortech-pro' )
        );
        return apply_filters( 'stortech_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'stortech_pro_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function stortech_pro_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'stortech-pro' ),
            'off'       => esc_html__( 'No', 'stortech-pro' )
        );
        return apply_filters( 'stortech_pro_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'stortech_pro_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function stortech_pro_sortable_sections() {
        $options = stortech_pro_get_theme_options();
        $sections = array();
        if ( $options['home_layout'] == 'first-design' ) {
             $sections = array(
                'introduction'          => esc_html__( 'Introduction', 'stortech-pro' ),
                'slider'                => esc_html__( 'Main Slider', 'stortech-pro' ),
                'product_layout_short_des' => esc_html__( 'Product Short Description', 'stortech-pro' ),
                'product_layout_cta' => esc_html__( 'Product CTA', 'stortech-pro' ),
                'product_layout_gallery' => esc_html__( 'Product Gallery', 'stortech-pro' ),
                'featured'              => esc_html__( 'Featured Section', 'stortech-pro' ),
                'accessories'           => esc_html__( 'Accessories Section', 'stortech-pro' ),
                'product_layout_features'   => esc_html__( 'Product Features Section', 'stortech-pro' ),
                'product_layout_design'     => esc_html__( 'Product Design Section', 'stortech-pro' ),
                'product_layout_zoom'       => esc_html__( 'Product Zoom Section', 'stortech-pro' ),
                'product_layout_similar_product'=> esc_html__( 'Similar Product Section', 'stortech-pro' ),
                'masonry_product'      => esc_html__( 'Masonry Product Section', 'stortech-pro' ),
                'recent_product'       => esc_html__( 'Recent Product Section', 'stortech-pro' ),
                'second_featured_product' => esc_html__( 'Featured Product Second Section', 'stortech-pro' ),
                'popular_product'       => esc_html__( 'Popular Product Section', 'stortech-pro' ),
                'product_collection'    => esc_html__( 'Product Collection Section', 'stortech-pro' ),
                'services'       => esc_html__( 'Services Section', 'stortech-pro' ),
                'about_us'       => esc_html__( 'Business About Us Section', 'stortech-pro' ),
                'counter'       => esc_html__( 'Business Counter Section', 'stortech-pro' ),
                'team'       => esc_html__( 'Business Team Section', 'stortech-pro' ),
                'latest_product'        => esc_html__( 'Latest Product Section', 'stortech-pro' ),
                'featured_blog'                  => esc_html__( 'Featured Blog Section', 'stortech-pro' ),
                'popular_blog'                  => esc_html__( 'Polular Blog Section', 'stortech-pro' ),
                'blog'                  => esc_html__( 'Blog Section', 'stortech-pro' ),
                'testimonial'           => esc_html__( 'Testimonial Section', 'stortech-pro' ),
                'subscription'          => esc_html__( 'Subscription Section', 'stortech-pro' ),
            );
        }

        if ( $options['home_layout'] == 'product' ) {
            $sections = array(
                'introduction'          => esc_html__( 'Introduction', 'stortech-pro' ),
                'product_layout_short_des' => esc_html__( 'Product Short Description', 'stortech-pro' ),
                'product_layout_cta' => esc_html__( 'Product CTA', 'stortech-pro' ),
                'product_layout_gallery' => esc_html__( 'Product Gallery', 'stortech-pro' ),
                'featured'              => esc_html__( 'Featured Section', 'stortech-pro' ),
                'product_layout_design'     => esc_html__( 'Product Design Section', 'stortech-pro' ),
                'product_layout_zoom'       => esc_html__( 'Product Zoom Section', 'stortech-pro' ),
            );

        }

        if ( $options['home_layout'] == 'second-design' ) {
            $sections = array(
                'slider'                => esc_html__( 'Main Slider', 'stortech-pro' ),
                'masonry_product'      => esc_html__( 'Masonry Product Section', 'stortech-pro' ),
                'recent_product'       => esc_html__( 'Recent Product Section', 'stortech-pro' ),
                'second_featured_product' => esc_html__( 'Featured Product Second Section', 'stortech-pro' ),
                'popular_product'       => esc_html__( 'Popular Product Section', 'stortech-pro' ),
                'services'       => esc_html__( 'Services Section', 'stortech-pro' ),
                'blog'                  => esc_html__( 'Blog Section', 'stortech-pro' ),
                'subscription'          => esc_html__( 'Subscription Section', 'stortech-pro' ),
            );

        }

        if ( $options['home_layout'] == 'fifth-design' ) {
            $sections = array(
                'slider'                => esc_html__( 'Main Slider', 'stortech-pro' ),
                'services'       => esc_html__( 'Services Section', 'stortech-pro' ),
                'about_us'       => esc_html__( 'Business About Us Section', 'stortech-pro' ),
                'counter'       => esc_html__( 'Business Counter Section', 'stortech-pro' ),
                'team'       => esc_html__( 'Business Team Section', 'stortech-pro' ),
                'blog'                  => esc_html__( 'Blog Section', 'stortech-pro' ),
                'subscription'          => esc_html__( 'Subscription Section', 'stortech-pro' ),
            );

        }

        if ( $options['home_layout'] == 'third-design' ) {
            $sections = array(
                'slider'                => esc_html__( 'Main Slider', 'stortech-pro' ),
                'services'       => esc_html__( 'Services Section', 'stortech-pro' ),
                'product_collection'    => esc_html__( 'Product Collection Section', 'stortech-pro' ),
            );

        }

        if ( $options['home_layout'] == 'sixth-design' ) {
             $sections = array(
 
                'slider'                => esc_html__( 'Main Slider', 'stortech-pro' ),
        
                'featured_blog'                  => esc_html__( 'Featured Blog Section', 'stortech-pro' ),
                'popular_blog'                  => esc_html__( 'Polular Blog Section', 'stortech-pro' ),
                'blog'                  => esc_html__( 'Blog Section', 'stortech-pro' ),
              
            );
        }

       
        return apply_filters( 'stortech_pro_sortable_sections', $sections );
    }
endif;



if ( ! function_exists( 'stortech_pro_testimonial_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function stortech_pro_testimonial_content_type() {
        $stortech_pro_testimonial_content_type = array(
            'page'      => esc_html__( 'Page', 'stortech-pro' ),
            'post'      => esc_html__( 'Post', 'stortech-pro' ),
            'custom'  => esc_html__( 'Custom', 'stortech-pro' ),
        );

        $output = apply_filters( 'stortech_pro_testimonial_content_type', $stortech_pro_testimonial_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'stortech_pro_slider_product_content_type' ) ) :
    /**
     * List of slider product
     * @return array List of slider product.
     */
    function stortech_pro_slider_product_content_type() {
        $arr = array(
            'page'          => esc_html__( 'Page', 'stortech-pro' ),
            'post'          => esc_html__( 'Post', 'stortech-pro' ),
            'category'      => esc_html__( 'Post Category', 'stortech-pro' ),
        );
        if ( class_exists( 'WooCommerce' ) ) {
            $arr = array_merge( $arr, 
                array( 
                    'product'           => esc_html__( 'Product', 'stortech-pro' ), 
                    
                    ) 
                );
        }

        return apply_filters( 'stortech_pro_slider_options', $arr );
    }
endif;
if ( ! function_exists( 'stortech_pro_featured_product_content_type' ) ) :
    /**
     * List of featured product
     * @return array List of featured product.
     */
    function stortech_pro_featured_product_content_type() {
        $arr = array(
            'page'          => esc_html__( 'Page', 'stortech-pro' ),
            'post'          => esc_html__( 'Post', 'stortech-pro' ),
            'category'      => esc_html__( 'Post Category', 'stortech-pro' ),
        );
        if ( class_exists( 'WooCommerce' ) ) {
            $arr = array_merge( $arr, 
                array( 
                    'product'           => esc_html__( 'Product', 'stortech-pro' ), 
                    ) 
                );
        }

        return apply_filters( 'stortech_pro_featured_options', $arr );
    }
endif;

if ( ! function_exists( 'stortech_pro_accessories_product_content_type' ) ) :
    /**
     * List of accessories product
     * @return array List of accessories product.
     */
    function stortech_pro_accessories_product_content_type() {
        $arr = array(
            'page'          => esc_html__( 'Page', 'stortech-pro' ),
            'post'          => esc_html__( 'Post', 'stortech-pro' ),
            'category'      => esc_html__( 'Post Category', 'stortech-pro' ),
        );
        if ( class_exists( 'WooCommerce' ) ) {
            $arr = array_merge( $arr, 
                array( 
                    'product'           => esc_html__( 'Product', 'stortech-pro' ), 
                    ) 
                );
        }

        return apply_filters( 'stortech_pro_featured_options', $arr );
    }
endif;

if ( ! function_exists( 'stortech_pro_introduction_product_content_type' ) ) :
    /**
     * List of introduction product
     * @return array List of introduction product.
     */
    function stortech_pro_introduction_product_content_type() {
        $arr = array(
            'page'          => esc_html__( 'Page', 'stortech-pro' ),
            'post'          => esc_html__( 'Post', 'stortech-pro' ),
        );
        if ( class_exists( 'WooCommerce' ) ) {
            $arr = array_merge( $arr, 
                array( 
                    'product'           => esc_html__( 'Product', 'stortech-pro' ), 
                    ) 
                );
        }

        return apply_filters( 'stortech_pro_featured_options', $arr );
    }
endif;

if ( ! function_exists( 'stortech_pro_product_layout_similar_product_options' ) ) :
    /**
     * List of product_layout_similar_product options
     * @return array List of product_layout_similar_product options.
     */
    function stortech_pro_product_layout_similar_product_options() {
    
        if ( class_exists( 'WooCommerce' ) ) {
                $arr = array(
                'product'           => esc_html__( 'Product', 'stortech-pro' ),
                'product_cat'       => esc_html__( 'Product Category', 'stortech-pro' ),
                'recent_product'    => esc_html__( 'Recent Product', 'stortech-pro' ),
            );
        }

        return apply_filters( 'stortech_pro_product_layout_similar_product_options', $arr );
    }
endif;

if ( ! function_exists( 'stortech_pro_latest_product' ) ) :
    /**
     * List of latest product
     * @return array List of latest product.
     */
    function stortech_pro_latest_product() {
        $arr = array(
            'page'          => esc_html__( 'Page', 'stortech-pro' ),
            'post'          => esc_html__( 'Post', 'stortech-pro' ),
            'category'      => esc_html__( 'Post Category', 'stortech-pro' ),
        );
        if ( class_exists( 'WooCommerce' ) ) {
            $arr = array_merge( $arr, 
                array( 
                    'product'           => esc_html__( 'Product', 'stortech-pro' ), 
                    'product-category'  => esc_html__( 'Product Category', 'stortech-pro' ), 
                    'latest-product'    => esc_html__( 'Latest Products', 'stortech-pro' ), 
                    ) 
                );
        }

        return apply_filters( 'stortech_pro_latest_options', $arr );
    }
endif;

if ( ! function_exists( 'stortech_pro_recent_product_options' ) ) :
    /**
     * List of recent_product options
     * @return array List of recent_product options.
     */
    function stortech_pro_recent_product_options() {
    
        if ( class_exists( 'WooCommerce' ) ) {
                $arr = array(
                'product'           => esc_html__( 'Product', 'stortech-pro' ),
                'product_cat'       => esc_html__( 'Product Category', 'stortech-pro' ),
                'recent_product'    => esc_html__( 'Recent Product', 'stortech-pro' ),
            );
        }

        return apply_filters( 'stortech_pro_recent_product_options', $arr );
    }
endif;

if ( ! function_exists( 'stortech_pro_template_introduction_content_type' ) ) :
    /**
     * List of introduction content type
     * @return array List of introduction content type.
     */
    function stortech_pro_template_introduction_content_type() {
        $arr = array(
            'page'          => esc_html__( 'Page', 'stortech-pro' ),
            'post'          => esc_html__( 'Post', 'stortech-pro' ),
        );
        if ( class_exists( 'WooCommerce' ) ) {
            $arr = array_merge( $arr, 
                array( 
                    'product'           => esc_html__( 'Product', 'stortech-pro' ), 
                    ) 
                );
        }

        return apply_filters( 'stortech_pro_template_introduction_options', $arr );
    }
endif; 