<?php
/**
 * Product Zoom section
 *
 * This is the template for the content of about_us section
 *
 * @package Theme Palace
 * @subpackage Stortech Pro
 * @since Stortech Pro 1.0.0
 */
if ( ! function_exists( 'stortech_pro_add_about_us_section' ) ) :
    /**
    * Add about_us section
    *
    *@since Stortech Pro 1.0.0
    */
    function stortech_pro_add_about_us_section() {
        $options = stortech_pro_get_theme_options();
        // Check if about_us is enabled on frontpage
        $about_us_enable = apply_filters( 'stortech_pro_section_status', true, 'about_us_section_enable' );

        if( !in_array( $options['home_layout'], array( 'fifth-design', 'first-design' ) ) ){
            $about_us_enable = false;
        }

        if ( true !== $about_us_enable ) {
            return false;
        }
        // Get about_us section details
        $section_details = array();
        $section_details = apply_filters( 'stortech_pro_filter_about_us_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render about_us section now.
        stortech_pro_render_about_us_section( $section_details );
    }
endif;

if ( ! function_exists( 'stortech_pro_get_about_us_section_details' ) ) :
    /**
    * about_us section details.
    *
    * @since Stortech Pro 1.0.0
    * @param array $input about_us section details.
    */
    function stortech_pro_get_about_us_section_details( $input ) {
        $options = stortech_pro_get_theme_options();

        // Content type.
        $about_us_content_type  = $options['about_us_content_type'];
        
        $content = array();
        switch ( $about_us_content_type ) {

            case 'custom':
                $custom['title']        = ! empty( $options['about_us_title'] ) ? $options['about_us_title'] : '';
                $custom['excerpt']      = ! empty( $options['about_us_description'] ) ? $options['about_us_description'] : '';
                $custom['image']        = ! empty( $options['about_us_image'] ) ? $options['about_us_image'] : '';

                // Push to the main array.
                array_push( $content, $custom );
            break;

            case 'page':
                $page_id = ! empty( $options['about_us_content_page'] ) ? $options['about_us_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['about_us_content_post'] ) ? $options['about_us_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            default:
            break;
        }
        if ( 'custom' !== $about_us_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = stortech_pro_trim_content( 40 );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        endif;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// about_us section content details.
add_filter( 'stortech_pro_filter_about_us_section_details', 'stortech_pro_get_about_us_section_details' );


if ( ! function_exists( 'stortech_pro_render_about_us_section' ) ) :
  /**
   * Start about_us section
   *
   * @return string about_us content
   * @since Stortech Pro 1.0.0
   *
   */
   function stortech_pro_render_about_us_section( $content_details = array() ) {
        $options = stortech_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="stortech_pro_about_us_section">   
            <div id="business-about-us" class="page-section">
                <div class="wrapper">
                    <?php stortech_pro_section_tooltip( 'business-about-us' ); ?>
                    <?php foreach ( $content_details as $content ) :  ?>
                        <article class="<?php echo ! empty( $content['image'] ) ? 'has-post-thumbnail' : 'no-featured-image'; ?>">
                            <div class="featured-image" style="background-image:url('<?php echo esc_url( $content['image'] ); ?>')"></div>
                            <div class="entry-container">
                                <?php if ( ! empty( $content['title'] ) ) : ?>
                                    <header class="section-header">
                                        <h2 class="section-title"><?php echo esc_html( $content['title'] ); ?></h2>
                                    </header>
                                <?php endif; ?>                           

                                <?php if ( ! empty( $content['excerpt'] ) ) : ?>
                                    <div class="entry-content">
                                        <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                    </div><!-- .entry-content -->
                                <?php endif; ?>
                                <?php if ( !empty( $options['about_us_btn_label'] ) && !empty( $options['about_us_btn_url'] ) ) : ?>
                                    <div class="read-more">
                                        <a href="<?php echo esc_url($options['about_us_btn_url'] ); ?>" class="btn btn-fill" > <?php echo esc_html( $options['about_us_btn_label'] ) ?>                                  
                                        </a>
                                    </div>
                                <?php endif; ?>
                            </div><!-- .entry-container -->
                        </article>
                    <?php endforeach;?>
                </div><!-- .wrapper -->
            </div><!-- #business-about-us -->        
        </div>
            
<?php    }
endif;