<?php
/**
 * Counter section
 *
 * This is the template for the content of counter section
 *
 * @package Theme Palace
 * @subpackage Stortech Pro
 * @since Stortech Pro 1.0.0
 */
if ( ! function_exists( 'stortech_pro_add_counter_section' ) ) :
    /**
    * Add counter section
    *
    *@since Stortech Pro 1.0.0
    */
    function stortech_pro_add_counter_section() {
    	$options = stortech_pro_get_theme_options();
        // Check if counter is enabled on frontpage
        $counter_enable = apply_filters( 'stortech_pro_section_status', true, 'counter_section_enable' );

        if( !in_array( $options['home_layout'], array( 'fifth-design', 'first-design' ) )  ){
            $counter_enable = false;
        }

        if ( ! $counter_enable ) {
            return false;
        }

        // Render counter section now.
        stortech_pro_render_counter_section();
    }
endif;

if ( ! function_exists( 'stortech_pro_render_counter_section' ) ) :
  /**
   * Start counter section
   *
   * @return string counter content
   * @since Stortech Pro 1.0.0
   *
   */
   function stortech_pro_render_counter_section() {
        $options = stortech_pro_get_theme_options();
        $image = ( ! empty( $options['counter_image'] ) ) ? $options['counter_image'] : '' ;
        if ( $options['counter_count'] > 4 ) {
            $class = 4;
        } else {
            $class= $options['counter_count'];
        }
        ?>
        <div id="stortech_pro_counter_section">   
            <div id="business-counter" class="relative page-section" style="background-image: url('<?php echo esc_url( $image ); ?>');">
                <!-- supports col-1, col-2, col-3, col-4 -->
                <div class="overlay"></div>
                <div class="wrapper">
                    <?php stortech_pro_section_tooltip( 'business-counter' ); ?>
                    <div class="business-section-content clear col-<?php echo esc_attr( $class ); ?>">

                        <?php for ( $i=1; $i <= $options['counter_count']; $i++ ) :  
                            if ( isset( $options['counter_icon_' . $i] ) || isset( $options['counter_value_' . $i] ) || isset( $options['counter_text_' . $i] ) ) :
                            ?>
                            <article>
                                <header class="entry-header">
                                    <?php if ( !empty( $options['counter_icon_' . $i] ) ) { ?>
                                    <div class="counter-icon">
                                        <i class="fa <?php echo esc_html( $options['counter_icon_' . $i] ); ?>"></i>
                                    </div><!-- .counter-icon -->                        
                                    <?php } 
                                    if ( !empty( $options['counter_value_' . $i] ) ) { ?>
                                        <h3 class="counter-value"><?php echo esc_html( $options['counter_value_' . $i ] ); ?></h3>
                                        <div class="separator-line"></div>
                                    <?php } ?>
                                    
                                     <?php  if ( isset( $options['counter_text_' . $i] ) ) { ?>
                                        <h2 class="entry-title"><?php echo esc_html( $options['counter_text_' . $i ] ); ?></h2>
                                    <?php } ?>
                                </header>
                            </article>
                            <?php 
                            endif;
                        endfor; ?>

                    </div>
                </div><!-- .wrapper -->
            </div><!-- #counter -->
        </div>
            
        <?php
    }
endif;