<?php
/**
 * Blog section
 *
 * This is the template for the content of featured_blog section
 *
 * @package Theme Palace
 * @subpackage Stortech Pro
 * @since Stortech Pro 1.0.0
 */
if ( ! function_exists( 'stortech_pro_add_featured_blog_section' ) ) :
    /**
    * Add featured_blog section
    *
    *@since Stortech Pro 1.0.0
    */
    function stortech_pro_add_featured_blog_section() {
    	$options = stortech_pro_get_theme_options();
        // Check if featured_blog is enabled on frontpage
        $featured_blog_enable = apply_filters( 'stortech_pro_section_status', true, 'featured_blog_section_enable' );

        if(  !in_array( $options['home_layout'], array( 'sixth-design', 'first-design' ) ) ){
            $featured_blog_enable = false;
        
        }

        if ( true !== $featured_blog_enable ) {
            return false;
        }
        // Get featured_blog section details
        $section_details = array();
        $section_details = apply_filters( 'stortech_pro_filter_featured_blog_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render featured_blog section now.
        stortech_pro_render_featured_blog_section( $section_details );
    }
endif;

if ( ! function_exists( 'stortech_pro_get_featured_blog_section_details' ) ) :
    /**
    * featured_blog section details.
    *
    * @since Stortech Pro 1.0.0
    * @param array $input featured_blog section details.
    */
    function stortech_pro_get_featured_blog_section_details( $input ) {
        $options = stortech_pro_get_theme_options();

        // Content type.
        $featured_blog_content_type  = $options['featured_blog_content_type'];
        $featured_blog_count = ! empty( $options['featured_blog_count'] ) ? $options['featured_blog_count'] : 3;

        $content = array();
        switch ( $featured_blog_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $featured_blog_count; $i++ ) {
                    if ( ! empty( $options['featured_blog_content_page_' . $i] ) )
                        $page_ids[] = $options['featured_blog_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $featured_blog_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $featured_blog_count; $i++ ) {
                    if ( ! empty( $options['featured_blog_content_post_' . $i] ) )
                        $post_ids[] = $options['featured_blog_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $featured_blog_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['featured_blog_content_category'] ) ? $options['featured_blog_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $featured_blog_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break; 

            case 'recent':
                $cat_ids = ! empty( $options['featured_blog_category_exclude'] ) ? $options['featured_blog_category_exclude'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $featured_blog_count ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = stortech_pro_trim_content( 20 );
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : '';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

    
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// featured_blog section content details.
add_filter( 'stortech_pro_filter_featured_blog_section_details', 'stortech_pro_get_featured_blog_section_details' );


if ( ! function_exists( 'stortech_pro_render_featured_blog_section' ) ) :
  /**
   * Start featured_blog section
   *
   * @return string featured_blog content
   * @since Stortech Pro 1.0.0
   *
   */
   function stortech_pro_render_featured_blog_section( $content_details = array() ) {
        $options = stortech_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="stortech_pro_featured_blog_section"> 
            <div id="blog-featured-posts" class="relative page-section">
                <div class="wrapper">
                    <?php stortech_pro_section_tooltip( 'blog-featured-posts' ); ?>
                    <?php if (!empty( $options['featured_blog_title'] )): ?>
                        <div class="section-header">
                            <h2 class="section-title"><?php echo esc_html( $options['featured_blog_title'] ) ; ?></h2>
                        </div><!-- .section-header -->
                    <?php endif ?>
                    <div class="blog-section-content clear">
                        <?php foreach ( $content_details as $content ) { 
                             $image = $content['image'] == '' ? get_template_directory_uri().'/assets/uploads/no-featured-image-590x650.jpg' : $content['image'] ;
                        ?>
                             <article>
                                <div class="blog-featured-image" style="background-image: url('<?php echo esc_url(  $image ); ?>');">
                                        <a href="<?php echo esc_url( $content['url'] ) ; ?>" class="post-thumbnail-link"></a>
                                    </div><!-- .featured-image -->

                                    <div class="entry-container">
                                        <?php 
                                        $featured_blog_content_type  = $options['featured_blog_content_type']; 
                                         if ( 'page' != $featured_blog_content_type ) : ?> 
                                            <span class="cat-links">
                                            <?php the_category( '', '', $content['id'] ); ?>
                                        </span>
                                        <?php endif; ?>
                                        

                                        <header class="entry-header">
                                            <h2 class="entry-title">
                                                <a href="<?php echo esc_url( $content['url'] ) ; ?>">
                                                    <?php echo esc_html( $content['title'] ) ; ?>
                                                </a>
                                            </h2>
                                        </header>

                                        <?php stortech_pro_posted_on( $content['id'] ); ?>
                                    </div><!-- .entry-container -->
                            </article>
                       <?php } ?>
                    </div>
                </div><!-- .wrapper -->
            </div>  
        </div>
       
    <?php }
endif;