<?php
/**
 * Slider section
 *
 * This is the template for the content of second_featured_product section
 *
 * @package Theme Palace
 * @subpackage Stortech Pro
 * @since Stortech Pro 1.0.0
 */
if ( ! function_exists( 'stortech_pro_add_second_featured_product_section' ) ) :
    /**
    * Add second_featured_product section
    *
    *@since Stortech Pro 1.0.0
    */
    function stortech_pro_add_second_featured_product_section() {
    	$options = stortech_pro_get_theme_options();
        // Check if second_featured_product is enabled on frontpage
        $second_featured_product_enable = apply_filters( 'stortech_pro_section_status', true, 'second_featured_product_section_enable' );

        $home_layout =$options['home_layout'];

        if( in_array ( $home_layout, array( 'third-design', 'fifth-design', 'sixth-design', 'product' ) ) ) {
            $second_featured_product_enable = false;
        }

        if ( true !== $second_featured_product_enable ) {
            return false;
        }
        // Get second_featured_product section details
        $section_details = array();
        $section_details = apply_filters( 'stortech_pro_filter_second_featured_product_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render second_featured_product section now.
        stortech_pro_render_second_featured_product_section( $section_details );
    }
endif;

if ( ! function_exists( 'stortech_pro_get_second_featured_product_section_details' ) ) :
    /**
    * second_featured_product section details.
    *
    * @since Stortech Pro 1.0.0
    * @param array $input second_featured_product section details.
    */
    function stortech_pro_get_second_featured_product_section_details( $input ) {
        $options = stortech_pro_get_theme_options();

        // Content type.
        $second_featured_product_content_type  = $options['second_featured_product_content_type'];
        $second_featured_product_count = ! empty( $options['second_featured_product_count'] ) ? $options['second_featured_product_count'] : 2;
        
        $content = array();
        switch ( $second_featured_product_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $second_featured_product_count; $i++ ) {
                    if ( ! empty( $options['second_featured_product_content_page_' . $i] ) )
                        $page_ids[] = $options['second_featured_product_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $second_featured_product_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $second_featured_product_count; $i++ ) {
                    if ( ! empty( $options['second_featured_product_content_post_' . $i] ) )
                        $post_ids[] = $options['second_featured_product_content_post_' . $i];
                }
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $second_featured_product_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['second_featured_product_content_category'] ) ? $options['second_featured_product_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $second_featured_product_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'product':
                $page_ids = array();

                for ( $i = 1; $i <= $second_featured_product_count; $i++ ) {
                    if ( ! empty( $options['second_featured_product_product_content_page_' . $i] ) )
                        $page_ids[] = $options['second_featured_product_product_content_page_' . $i];
                }

                $args = array(
                    'post_type'         => 'product',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => count( $page_ids ),
                    'orderby'           => 'post__in',
                    );
            break;

            case 'product-cat':
                $cat_id = ! empty( $options['second_featured_product_product_category'] ) ? $options['second_featured_product_product_category'] : '';

                $args = array(
                'post_type'         => 'product',
                'posts_per_page'    => absint( $second_featured_product_count ),
                'tax_query'         => array(
                    array(
                        'taxonomy'  => 'product_cat',
                        'field'     => 'id',
                        'terms'     => $cat_id
                    )
                ) );
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = stortech_pro_trim_content( 10 );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// second_featured_product section content details.
add_filter( 'stortech_pro_filter_second_featured_product_section_details', 'stortech_pro_get_second_featured_product_section_details' );


if ( ! function_exists( 'stortech_pro_render_second_featured_product_section' ) ) :
  /**
   * Start second_featured_product section
   *
   * @return string second_featured_product content
   * @since Stortech Pro 1.0.0
   *
   */
   function stortech_pro_render_second_featured_product_section( $content_details = array() ) {
        $options = stortech_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="stortech_pro_second_featured_product_section">   
            <div id="featured-products" class="relative page-section same-background">
                <?php stortech_pro_section_tooltip( 'featured-products' ); ?>
                    <div class="section-content clear col-2">  
                    <?php $i = 1 ; 
                    foreach ($content_details as $content): 
                        $image = $content['image'] == '' ? get_template_directory_uri().'/assets/uploads/no-featured-image-590x650.jpg' : $content['image'] ;
                    ?>
                        <article>
                            <div class="featured-image" style="background-image:url('<?php echo esc_url( $image ); ?>');">
                                    <div class="overlay"></div>
                                    <div class="entry-container">
                                        <header class="entry-header">
                                             <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>" ><?php echo esc_html( $content['title'] ); ?></a></h2>
                                        </header>
                                        <div class="entry-content">
                                            <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                        </div><!-- .entry-content -->
                                          <?php if ( !empty( $options['second_featured_product_btn_label_'.$i] ) && !empty( $options['second_featured_product_btn_url_'.$i] ) ) : ?>
                                                <div class="read-more">
                                                    <a href="<?php echo esc_url($options['second_featured_product_btn_url_'.$i] ); ?>" class="btn" > <?php echo esc_html( $options['second_featured_product_btn_label_'.$i] )  ?>                                  
                                                    </a>
                                                </div>
                                        <?php endif; ?>
                                    </div><!-- .entry-container -->
                                </div><!-- .featured-image -->
                        </article>
                    <?php $i++; endforeach ; ?>
                </div>
            </div><!-- #featured-second_featured_product -->
        </div>
        
                       
    <?php }
endif;