<?php
/**
 * Introduction section
 *
 * This is the template for the content of introduction section
 *
 * @package Theme Palace
 * @subpackage Stortech Pro
 * @since Stortech Pro 1.0.0
 */
if ( ! function_exists( 'stortech_pro_add_introduction_section' ) ) :
    /**
    * Add introduction section
    *
    *@since Stortech Pro 1.0.0
    */
    function stortech_pro_add_introduction_section() {
        $options = stortech_pro_get_theme_options();
        // Check if introduction is enabled on frontpage
        $introduction_enable = apply_filters( 'stortech_pro_section_status', true, 'introduction_section_enable' );

        if( !in_array( $options['home_layout'], array( 'product', 'first-design' ) ) ){
            $introduction_enable = false;
        }

        if ( true !== $introduction_enable ) {
            return false;
        }
        // Get introduction section details
        $section_details = array();
        $section_details = apply_filters( 'stortech_pro_filter_introduction_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render introduction section now.
        stortech_pro_render_introduction_section( $section_details );
    }
endif;

if ( ! function_exists( 'stortech_pro_get_introduction_section_details' ) ) :
    /**
    * introduction section details.
    *
    * @since Stortech Pro 1.0.0
    * @param array $input introduction section details.
    */
    function stortech_pro_get_introduction_section_details( $input ) {
        $options = stortech_pro_get_theme_options();

        // Content type.
        $introduction_content_type  = $options['introduction_content_type'];
        
        $content = array();
        switch ( $introduction_content_type ) {

            case 'page':
                $page_id = ! empty( $options['introduction_content_page'] ) ? $options['introduction_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['introduction_content_post'] ) ? $options['introduction_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            case 'product':
                $product_ids = ! empty( $options['introduction_product_content_page'] ) ? $options['introduction_product_content_page'] : '';
                $args = array(
                    'post_type'         => 'product',
                    'post__in'          => (array)$product_ids,
                    'posts_per_page'    => 1,
                    'orderby'           => 'post__in',
                    );
            break;

            default:
            break;
        }

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = stortech_pro_trim_content( 40 );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// introduction section content details.
add_filter( 'stortech_pro_filter_introduction_section_details', 'stortech_pro_get_introduction_section_details' );


if ( ! function_exists( 'stortech_pro_render_introduction_section' ) ) :
  /**
   * Start introduction section
   *
   * @return string introduction content
   * @since Stortech Pro 1.0.0
   *
   */
   function stortech_pro_render_introduction_section( $content_details = array() ) {
        $options = stortech_pro_get_theme_options();
        $readmore = ! empty( $options['introduction_btn_title'] ) ? $options['introduction_btn_title'] : esc_html__( 'Read More', 'stortech-pro' );

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="stortech_pro_introduction_section">   
                 <div id="introduction" class="page-section">
                <div class="wrapper">
                    <?php stortech_pro_section_tooltip( 'introduction' ); ?>
                    <?php foreach ( $content_details as $content ) :  ?>
                        <article>
                            <div class="entry-container">
                            <?php if ( ! empty( $content['title'] ) ) : ?>
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                        <?php if ( !empty( $options['introduction_subtitle'] ) ): ?>
                                            <span><?php echo esc_html($options['introduction_subtitle']); ?></span>
                                        <?php endif ?>
                                        
                                    </header>
                                <?php endif; ?>
                            <?php if ( ! empty( $content['image'] ) ) : ?>
                                <div class="featured-image">  
                                     <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>" ></a>
                                </div><!-- .featured-image -->
                            <?php endif; ?>

                            

                                <?php if ( ! empty( $content['excerpt'] ) ) : ?>
                                    <div class="entry-content">
                                        <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                        <?php
                                           $introduction_content_type  = $options['introduction_content_type'];

                                            if ( $introduction_content_type == 'product' ): ?>
                                                <span> <?php
                                                 if (!empty($options['introduction_product_text'])) {
                                                        echo esc_html($options['introduction_product_text']);
                                                    } 
                                                 $product = new WC_Product( $content['id'] );
                                                        echo $product->get_price_html(); ?></span>
                                            <?php endif; ?>
                                    </div><!-- .entry-content -->
                                <?php endif; ?>
                            </div><!-- .entry-container -->
                        </article>
                    <?php endforeach;?>
                </div><!-- .wrapper -->
            </div><!-- #business-introduction-us -->   
        </div>
                
<?php    }
endif;