<?php
/**
 * Slider section
 *
 * This is the template for the content of masonry_product section
 *
 * @package Theme Palace
 * @subpackage Stortech Pro
 * @since Stortech Pro 1.0.0
 */
if ( ! function_exists( 'stortech_pro_add_masonry_product_section' ) ) :
    /**
    * Add masonry_product section
    *
    *@since Stortech Pro 1.0.0
    */
    function stortech_pro_add_masonry_product_section() {
    	$options = stortech_pro_get_theme_options();
        // Check if masonry_product is enabled on frontpage
        $masonry_product_enable = apply_filters( 'stortech_pro_section_status', true, 'masonry_product_section_enable' );

        $home_layout =$options['home_layout'];

        if( in_array ( $home_layout, array( 'third-design', 'fifth-design', 'sixth-design', 'product' ) ) ) {
            $masonry_product_enable = false;
        }

        if ( true !== $masonry_product_enable ) {
            return false;
        }
        // Get masonry_product section details
        $section_details = array();
        $section_details = apply_filters( 'stortech_pro_filter_masonry_product_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render masonry_product section now.
        stortech_pro_render_masonry_product_section( $section_details );
    }
endif;

if ( ! function_exists( 'stortech_pro_get_masonry_product_section_details' ) ) :
    /**
    * masonry_product section details.
    *
    * @since Stortech Pro 1.0.0
    * @param array $input masonry_product section details.
    */
    function stortech_pro_get_masonry_product_section_details( $input ) {
        $options = stortech_pro_get_theme_options();

        // Content type.
        $masonry_product_content_type  = $options['masonry_product_content_type'];
        $masonry_product_count = ! empty( $options['masonry_product_count'] ) ? $options['masonry_product_count'] : 3;
        
        $content = array();
        switch ( $masonry_product_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $masonry_product_count; $i++ ) {
                    if ( ! empty( $options['masonry_product_content_page_' . $i] ) )
                        $page_ids[] = $options['masonry_product_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $masonry_product_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $masonry_product_count; $i++ ) {
                    if ( ! empty( $options['masonry_product_content_post_' . $i] ) )
                        $post_ids[] = $options['masonry_product_content_post_' . $i];
                }
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $masonry_product_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['masonry_product_content_category'] ) ? $options['masonry_product_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $masonry_product_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'product':
                $page_ids = array();

                for ( $i = 1; $i <= $masonry_product_count; $i++ ) {
                    if ( ! empty( $options['masonry_product_product_content_page_' . $i] ) )
                        $page_ids[] = $options['masonry_product_product_content_page_' . $i];
                }

                $args = array(
                    'post_type'         => 'product',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => count( $page_ids ),
                    'orderby'           => 'post__in',
                    );
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = stortech_pro_trim_content( 10 );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// masonry_product section content details.
add_filter( 'stortech_pro_filter_masonry_product_section_details', 'stortech_pro_get_masonry_product_section_details' );


if ( ! function_exists( 'stortech_pro_render_masonry_product_section' ) ) :
  /**
   * Start masonry_product section
   *
   * @return string masonry_product content
   * @since Stortech Pro 1.0.0
   *
   */
   function stortech_pro_render_masonry_product_section( $content_details = array() ) {
        $options = stortech_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="stortech_pro_masonry_product_section"> 
            <div id="masonry" class="relative">
                <?php stortech_pro_section_tooltip( 'masonry' ); ?>
                <div class="grid clear">   
                    <?php $i = 1 ; 
                    foreach ($content_details as $content): 
                        $image = $content['image'] == '' ? get_template_directory_uri().'/assets/uploads/no-featured-image-590x650.jpg' : $content['image'] ;
                    ?>
                        <article class="grid-item" >
                            <div class="featured-image" style="background-image:url('<?php echo esc_url( $image ); ?>');">
                                    <div class="entry-container">
                                        <header class="entry-header">
                                             <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>" ><?php echo esc_html( $content['title'] ); ?></a></h2>
                                        </header>
                                    </div><!-- .entry-container -->
                                </div><!-- .featured-image -->
                        </article>
                    <?php $i++; endforeach ; ?>
                </div>
            </div><!-- #featured-masonry_product -->  
        </div>
        
                       
    <?php }
endif;