<?php
/**
 * Blog section
 *
 * This is the template for the content of popular_blog section
 *
 * @package Theme Palace
 * @subpackage Stortech Pro
 * @since Stortech Pro 1.0.0
 */
if ( ! function_exists( 'stortech_pro_add_popular_blog_section' ) ) :
    /**
    * Add popular_blog section
    *
    *@since Stortech Pro 1.0.0
    */
    function stortech_pro_add_popular_blog_section() {
        $options = stortech_pro_get_theme_options();
        // Check if popular_blog is enabled on frontpage
        $popular_blog_enable = apply_filters( 'stortech_pro_section_status', true, 'popular_blog_section_enable' );

        if( !in_array( $options['home_layout'], array( 'sixth-design', 'first-design' ) )){
            $popular_blog_enable = false;
        
        }

        if ( true !== $popular_blog_enable ) {
            return false;
        }
        // Get popular_blog section details
        $section_details = array();
        $section_details = apply_filters( 'stortech_pro_filter_popular_blog_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render popular_blog section now.
        stortech_pro_render_popular_blog_section( $section_details );
    }
endif;

if ( ! function_exists( 'stortech_pro_get_popular_blog_section_details' ) ) :
    /**
    * popular_blog section details.
    *
    * @since Stortech Pro 1.0.0
    * @param array $input popular_blog section details.
    */
    function stortech_pro_get_popular_blog_section_details( $input ) {
        $options = stortech_pro_get_theme_options();

        // Content type.
        $popular_blog_content_type  = $options['popular_blog_content_type'];
        $popular_blog_count = ! empty( $options['popular_blog_count'] ) ? $options['popular_blog_count'] : 3;

        $content = array();
        switch ( $popular_blog_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $popular_blog_count; $i++ ) {
                    if ( ! empty( $options['popular_blog_content_page_' . $i] ) )
                        $page_ids[] = $options['popular_blog_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $popular_blog_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $popular_blog_count; $i++ ) {
                    if ( ! empty( $options['popular_blog_content_post_' . $i] ) )
                        $post_ids[] = $options['popular_blog_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $popular_blog_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['popular_blog_content_category'] ) ? $options['popular_blog_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $popular_blog_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'recent':
                $cat_ids = ! empty( $options['popular_blog_category_exclude'] ) ? $options['popular_blog_category_exclude'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $popular_blog_count ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = stortech_pro_trim_content( 20 );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : '';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

    
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// popular_blog section content details.
add_filter( 'stortech_pro_filter_popular_blog_section_details', 'stortech_pro_get_popular_blog_section_details' );


if ( ! function_exists( 'stortech_pro_render_popular_blog_section' ) ) :
  /**
   * Start popular_blog section
   *
   * @return string popular_blog content
   * @since Stortech Pro 1.0.0
   *
   */
   function stortech_pro_render_popular_blog_section( $content_details = array() ) {
        $options = stortech_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="stortech_pro_popular_blog_section">  
                <div id="blog-popular-posts" class="relative page-section">
            <?php stortech_pro_section_tooltip( 'blog-popular-posts' ); ?>
                <div class="wrapper">
                    <?php if (!empty( $options['popular_blog_title'] )): ?>
                        <div class="section-header">
                            <h2 class="section-title"><?php echo esc_html( $options['popular_blog_title'] ) ; ?></h2>
                        </div><!-- .section-header -->
                    <?php endif ?>

                    <div class="col-2 clear">
                        <?php foreach ( $content_details as $content ) { 
                             $image = $content['image'] == '' ? get_template_directory_uri().'/assets/uploads/no-featured-image-590x650.jpg' : $content['image'] ;
                        ?>
                        <article>
                            <div class="popular-post-item">
                                <div class="blog-featured-image">
                                    <a href="<?php echo esc_url( $content['url'] ) ; ?>"><img src="<?php echo esc_url(  $image ); ?>"></a>
                                </div><!-- .blog-featured-image -->

                                <div class="entry-container">
                                    <span class="cat-links">
                                    <?php the_category( '', '', $content['id'] ); ?>                             
                                    </span><!-- .cat-links -->

                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ) ; ?>"><?php echo esc_html( $content['title'] ) ; ?></a></h2>
                                    </header>

                                    <?php stortech_pro_posted_on( $content['id'] ); ?>

                                    <div class="entry-content">
                                        <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                    </div><!-- .entry-content -->

                                    <div class="read-more">
                                        <?php if ( !empty( $options['popular_blog_btn_label'] ) ) : ?>
                                        <a href="<?php echo esc_url($content['url']); ?>" > <?php echo esc_html( $options['popular_blog_btn_label'] ) ?></a>
                                    <?php endif; ?>
                                    </div><!-- .read-more -->
                                </div><!-- .entry-container -->
                            </div><!-- .popular-post-item -->
                        </article>
                    <?php } ?>
                    </div><!-- .blog-section-content -->
                </div><!-- .wrapper -->
            </div><!-- #blog-popular-posts --> 
        </div>
        
    <?php }
endif;