<?php
/**
 * popular_product section
 *
 * This is the template for the content of popular_product section
 *
 * @package Theme Palace
 * @subpackage Stortech Pro
 * @since Stortech Pro 1.0.0
 */
if ( ! function_exists( 'stortech_pro_add_popular_product_section' ) ) :
    /**
    * Add popular_product section
    *
    *@since Stortech Pro 1.0.0
    */
    function stortech_pro_add_popular_product_section() {
        $options = stortech_pro_get_theme_options();
        // Check if popular_product is enabled on frontpage
        $popular_product_enable = apply_filters( 'stortech_pro_section_status', true, 'popular_product_section_enable' );

        $home_layout =$options['home_layout'];

        if( in_array ( $home_layout, array( 'third-design', 'fifth-design', 'sixth-design', 'product' ) ) ) {
            $popular_product_enable = false;
        }

        if ( true !== $popular_product_enable ) {
            return false;
        }
        // Get popular_product section details
        $section_details = array();
        $section_details = apply_filters( 'stortech_pro_filter_popular_product_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }
        if ( !class_exists('WooCommerce') ) {
            return;
        }
        // Render popular_product section now.
        stortech_pro_render_popular_product_section( $section_details );
    }
endif;

if ( ! function_exists( 'stortech_pro_get_popular_product_section_details' ) ) :
    /**
    * popular_product section details.
    *
    * @since Stortech Pro 1.0.0
    * @param array $input popular_product section details.
    */
    function stortech_pro_get_popular_product_section_details( $input ) {
        $options = stortech_pro_get_theme_options();

        // Content type.
        $popular_product_content_type  = $options['popular_product_content_type'];     
        $popular_product_count = ! empty( $options['popular_product_count'] ) ? $options['popular_product_count'] : 4; 
        
        $content = array();
        $content = array();
        switch ( $popular_product_content_type ) {

            case 'popular_product':
                $args = array(
                    'post_type'             => 'product',
                    'posts_per_page'        => $popular_product_count,
                    'ignore_sticky_posts'   => true,
                    );
            break;

            case 'product':
                $page_ids = array();

                for ( $i = 1; $i <= $popular_product_count; $i++ ) {
                    if ( ! empty( $options['popular_product_content_page_' . $i] ) )
                        $page_ids[] = $options['popular_product_content_page_' . $i];
                }

                $args = array(
                    'post_type'         => 'product',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => count( $page_ids ),
                    'orderby'           => 'post__in',
                    );
            break;
            case 'product_cat':
                $cat_id = ! empty( $options['popular_product_category'] ) ? $options['popular_product_category'] : '';

                $args = array(
                'post_type'         => 'product',
                'posts_per_page'    => absint( $popular_product_count ),
                'tax_query'         => array(
                    array(
                        'taxonomy'  => 'product_cat',
                        'field'     => 'id',
                        'terms'     => $cat_id
                    )
                ) );
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = stortech_pro_trim_content( 20 );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : '';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        
    
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// popular_product section content details.
add_filter( 'stortech_pro_filter_popular_product_section_details', 'stortech_pro_get_popular_product_section_details' );


if ( ! function_exists( 'stortech_pro_render_popular_product_section' ) ) :
  /**
   * Start popular_product section
   *
   * @return string popular_product content
   * @since Stortech Pro 1.0.0
   *
   */
   function stortech_pro_render_popular_product_section( $content_details = array() ) {
        $options = stortech_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="stortech_pro_popular_product_section">   
             <div id="popular-products" class="relative page-section same-background">
            <?php stortech_pro_section_tooltip( 'popular-products' ); ?>
                <div class="wrapper">
                    <?php if (!empty( $options['popular_product_title'] ) || !empty( $options['popular_product_title'] ) ): ?>
                        <div class="section-header">
                            <h2 class="section-title"><?php echo esc_html( $options['popular_product_title'] ) ; ?></h2>
                            <p class="subtitle"><?php echo esc_html( $options['popular_product_subtitle'] ) ; ?></p>
                        </div><!-- .section-header -->
                    <?php endif ?>

                    <div class="section-content">
                        <ul class="products col-4">
                            <?php foreach ( $content_details as $content ): 
                                $image = $content['image'] == '' ? get_template_directory_uri().'/assets/uploads/no-featured-image-590x650.jpg' : $content['image'] ;
                            ?>
                                <li class="product featured-products">
                                    <div class="post-thumbnail">
                                        <a href="<?php echo esc_url( $content['url'] ) ; ?>" class="woocommerce-LoopProduct-link woocommerce-loop-product__link">
                                        <?php 
                                            $product = new WC_Product( $content['id'] );
                                            if ( $product->get_sale_price() ): 
                                        ?>
                                        <span class="onsale">
                                            <?php esc_html_e('Sale!', 'stortech-pro'); ?>
                                        </span>
                                        <?php endif ?>
                                        <img width="330" height="400" src="<?php echo esc_url($image); ?>">
                                        <h2 class="woocommerce-loop-product__title"><?php echo esc_html( $content['title'] ) ?></h2></a>
                                        <span class="price">
                                             <?php 
                                                $product = new WC_Product( $content['id'] );
                                                echo $product->get_price_html();
                                            ?>
                                        </span>
                                        </a>
                                    </div><!-- .post-thumbnail -->                         
                                </li>
                            <?php endforeach ?>
                        </ul><!-- .product-slider -->                        
                        <?php if ( !empty( $options['popular_btn_label'] ) && !empty( $options['popular_btn_url'] ) ) : ?>
                            <div class="read-more">
                                <a href="<?php echo esc_url($options['popular_btn_url'] ); ?>" class="btn btn-fill" > <?php echo esc_html( $options['popular_btn_label'] ) ?>                                  
                                </a>
                            </div>
                        <?php endif; ?>
                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div>
        </div>
     
    <?php }
endif;