<?php
/**
 * Product Collection section
 *
 * This is the template for the content of product_collection section
 *
 * @package Theme Palace
 * @subpackage Stortech Pro
 * @since Stortech Pro 1.0.0
 */
if ( ! function_exists( 'stortech_pro_add_product_collection_section' ) ) :
    /**
    * Add product_collection section
    *
    *@since Stortech Pro 1.0.0
    */
    function stortech_pro_add_product_collection_section() {
        $options = stortech_pro_get_theme_options();
        // Check if product_collection is enabled on frontpage
        $product_collection_enable = apply_filters( 'stortech_pro_section_status', true, 'product_collection_section_enable' );

        if( !($options['home_layout'] == 'third-design' || $options['home_layout'] == 'first-design' )    ){
            $product_collection_enable = false;
        }

        if ( true !== $product_collection_enable ) {
            return false;
        }
        // Get product_collection section details
        $section_details = array();
        $section_details = apply_filters( 'stortech_pro_filter_product_collection_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render product_collection section now.
        stortech_pro_render_product_collection_section( $section_details );
    }
endif;

if ( ! function_exists( 'stortech_pro_get_product_collection_section_details' ) ) :
    /**
    * product_collection section details.
    *
    * @since Stortech Pro 1.0.0
    * @param array $input product_collection section details.
    */
    function stortech_pro_get_product_collection_section_details( $input ) {
        $options = stortech_pro_get_theme_options();

        // Content type.
        $product_collection_content_type  = $options['product_collection_content_type'];
        $product_collection_count = ! empty( $options['product_collection_count'] ) ? $options['product_collection_count'] : 3;
        
        $content = array();
        switch ( $product_collection_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $product_collection_count; $i++ ) {
                    if ( ! empty( $options['product_collection_content_page_' . $i] ) )
                        $page_ids[] = $options['product_collection_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $product_collection_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $product_collection_count; $i++ ) {
                    if ( ! empty( $options['product_collection_content_post_' . $i] ) )
                        $post_ids[] = $options['product_collection_content_post_' . $i];
                }
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $product_collection_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['product_collection_content_category'] ) ? $options['product_collection_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $product_collection_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'product':
                $page_ids = array();

                for ( $i = 1; $i <= $product_collection_count; $i++ ) {
                    if ( ! empty( $options['product_collection_product_content_page_' . $i] ) )
                        $page_ids[] = $options['product_collection_product_content_page_' . $i];
                }

                $args = array(
                    'post_type'         => 'product',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => count( $page_ids ),
                    'orderby'           => 'post__in',
                    );
            break;

            case 'product-cat':
                $cat_id = ! empty( $options['product_collection_product_category'] ) ? $options['product_collection_product_category'] : '';

                $args = array(
                'post_type'         => 'product',
                'posts_per_page'    => absint( $product_collection_count ),
                'tax_query'         => array(
                    array(
                        'taxonomy'  => 'product_cat',
                        'field'     => 'id',
                        'terms'     => $cat_id
                    )
                ) );
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = stortech_pro_trim_content( 20 );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// product_collection section content details.
add_filter( 'stortech_pro_filter_product_collection_section_details', 'stortech_pro_get_product_collection_section_details' );


if ( ! function_exists( 'stortech_pro_render_product_collection_section' ) ) :
  /**
   * Start product_collection section
   *
   * @return string product_collection content
   * @since Stortech Pro 1.0.0
   *
   */
   function stortech_pro_render_product_collection_section( $content_details = array() ) {
        $options = stortech_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="stortech_pro_product_collection_section">   
            <div id="watch" class="product-collection">   
                <?php stortech_pro_section_tooltip( 'product-collection-class' ); ?>
                <?php $i = 1 ; 
                foreach ($content_details as $content): 
                    $image = $content['image'] == '' ? get_template_directory_uri().'/assets/uploads/no-featured-image-590x650.jpg' : $content['image'] ;
                ?>
                    <article style="background-image:url('<?php echo esc_url( $image ); ?>');">
                        <div class="overlay"></div>
                        <div class="wrapper">
                            <div class="entry-container">

                                <header class="entry-header">
                                    <?php if (!empty($options['product_collection_subtitle_'. $i ] )): ?>
                                        <p><?php echo esc_html($options['product_collection_subtitle_'. $i ] ) ?></p>
                                    <?php endif ?>
                                    <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>" ><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>

                                <div class="entry-content">
                                   <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                </div><!-- .entry-content-->

                                <?php if ( !empty( $options['product_collection_btn_label'] ) ) : ?>
                                    <div class="read-more">
                                        <a href="<?php echo esc_url($content['url']); ?>" class="btn btn-fill" > <?php echo esc_html( $options['product_collection_btn_label'] ) ?></a>
                                    </div><!-- .read-more -->   
                                <?php endif; ?>                       
                            </div><!-- .featured-content-wrapper -->
                        </div><!-- .wrapper -->
                    </article>
                <?php $i++; endforeach ; ?>
            </div><!-- #featured-product_collection -->
        </div>
        
                       
    <?php }
endif;