<?php
/**
 * Introduction section
 *
 * This is the template for the content of product_layout_cta section
 *
 * @package Theme Palace
 * @subpackage Stortech Pro
 * @since Stortech Pro 1.0.0
 */
if ( ! function_exists( 'stortech_pro_add_product_layout_cta_section' ) ) :
    /**
    * Add product_layout_cta section
    *
    *@since Stortech Pro 1.0.0
    */
    function stortech_pro_add_product_layout_cta_section() {
        $options = stortech_pro_get_theme_options();
        // Check if product_layout_cta is enabled on frontpage
        $product_layout_cta_enable = apply_filters( 'stortech_pro_section_status', true, 'product_layout_cta_section_enable' );

        if( !in_array( $options['home_layout'], array( 'product', 'first-design' ) ) ){
            $product_layout_cta_enable = false;
        }

        if ( true !== $product_layout_cta_enable ) {
            return false;
        }
        // Get product_layout_cta section details
        $section_details = array();
        $section_details = apply_filters( 'stortech_pro_filter_product_layout_cta_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render product_layout_cta section now.
        stortech_pro_render_product_layout_cta_section( $section_details );
    }
endif;

if ( ! function_exists( 'stortech_pro_get_product_layout_cta_section_details' ) ) :
    /**
    * product_layout_cta section details.
    *
    * @since Stortech Pro 1.0.0
    * @param array $input product_layout_cta section details.
    */
    function stortech_pro_get_product_layout_cta_section_details( $input ) {
        $options = stortech_pro_get_theme_options();

        // Content type.
        $product_layout_cta_content_type  = $options['product_layout_cta_content_type'];
        
        $content = array();
        switch ( $product_layout_cta_content_type ) {

            case 'custom':
                $custom['title']        = ! empty( $options['product_layout_cta_title'] ) ? $options['product_layout_cta_title'] : '';
                $custom['excerpt']      = ! empty( $options['product_layout_cta_description'] ) ? $options['product_layout_cta_description'] : '';
                $custom['image']        = ! empty( $options['product_layout_cta_image'] ) ? $options['product_layout_cta_image'] : '';

                // Push to the main array.
                array_push( $content, $custom );
            break;

            case 'page':
                $page_id = ! empty( $options['product_layout_cta_content_page'] ) ? $options['product_layout_cta_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['product_layout_cta_content_post'] ) ? $options['product_layout_cta_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            default:
            break;
        }
        if ( 'custom' !== $product_layout_cta_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = stortech_pro_trim_content( 40 );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        endif;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// product_layout_cta section content details.
add_filter( 'stortech_pro_filter_product_layout_cta_section_details', 'stortech_pro_get_product_layout_cta_section_details' );


if ( ! function_exists( 'stortech_pro_render_product_layout_cta_section' ) ) :
  /**
   * Start product_layout_cta section
   *
   * @return string product_layout_cta content
   * @since Stortech Pro 1.0.0
   *
   */
   function stortech_pro_render_product_layout_cta_section( $content_details = array() ) {
        $options = stortech_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="stortech_pro_product_layout_cta_section">   
            <?php foreach ( $content_details as $content ) :  ?>
                <div id="cta" style="background-image:url(<?php echo esc_url( $content['image'] ); ?>)">
                    <?php stortech_pro_section_tooltip( 'cta' ); ?>
                    <div class="overlay"></div>
                    <div class="wrapper">
                        <div class="cta-wrapper">
                            <div class="section-header">
                                <h2 class="section-title"><?php echo esc_html( $content['title'] ); ?>.</h2>
                            </div>
                            <div class="section-content">
                                <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                            </div><!-- .section-content -->
                        </div><!-- .cta-wrapper -->
                    </div><!-- .wrapper -->
                </div><!-- #cta -->
            <?php endforeach;?>    
        </div>
       
<?php    }
endif;