<?php
/**
 * Product Design section
 *
 * This is the template for the content of product_layout_design section
 *
 * @package Theme Palace
 * @subpackage Stortech Pro
 * @since Stortech Pro 1.0.0
 */
if ( ! function_exists( 'stortech_pro_add_product_layout_design_section' ) ) :
    /**
    * Add product_layout_design section
    *
    *@since Stortech Pro 1.0.0
    */
    function stortech_pro_add_product_layout_design_section() {
        $options = stortech_pro_get_theme_options();
        // Check if product_layout_design is enabled on frontpage
        $product_layout_design_enable = apply_filters( 'stortech_pro_section_status', true, 'product_layout_design_section_enable' );

        if( !in_array( $options['home_layout'], array( 'product', 'first-design' ) ) ){
            $product_layout_design_enable = false;
        }

        if ( true !== $product_layout_design_enable ) {
            return false;
        }
        // Get product_layout_design section details
        $section_details = array();
        $section_details = apply_filters( 'stortech_pro_filter_product_layout_design_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render product_layout_design section now.
        stortech_pro_render_product_layout_design_section( $section_details );
    }
endif;

if ( ! function_exists( 'stortech_pro_get_product_layout_design_section_details' ) ) :
    /**
    * product_layout_design section details.
    *
    * @since Stortech Pro 1.0.0
    * @param array $input product_layout_design section details.
    */
    function stortech_pro_get_product_layout_design_section_details( $input ) {
        $options = stortech_pro_get_theme_options();

        // Content type.
        $product_layout_design_content_type  = $options['product_layout_design_content_type'];
        
        $content = array();
        switch ( $product_layout_design_content_type ) {

            case 'custom':
                $custom['title']        = ! empty( $options['product_layout_design_title'] ) ? $options['product_layout_design_title'] : '';
                $custom['excerpt']      = ! empty( $options['product_layout_design_description'] ) ? $options['product_layout_design_description'] : '';
                $custom['image']        = ! empty( $options['product_layout_design_image'] ) ? $options['product_layout_design_image'] : '';

                // Push to the main array.
                array_push( $content, $custom );
            break;

            case 'page':
                $page_id = ! empty( $options['product_layout_design_content_page'] ) ? $options['product_layout_design_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['product_layout_design_content_post'] ) ? $options['product_layout_design_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            default:
            break;
        }
        if ( 'custom' !== $product_layout_design_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = stortech_pro_trim_content( 40 );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        endif;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// product_layout_design section content details.
add_filter( 'stortech_pro_filter_product_layout_design_section_details', 'stortech_pro_get_product_layout_design_section_details' );


if ( ! function_exists( 'stortech_pro_render_product_layout_design_section' ) ) :
  /**
   * Start product_layout_design section
   *
   * @return string product_layout_design content
   * @since Stortech Pro 1.0.0
   *
   */
   function stortech_pro_render_product_layout_design_section( $content_details = array() ) {
        $options = stortech_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="stortech_pro_product_layout_design_section">   
              <div id="design" class="page-section product-design <?php $options['home_layout'] == 'product' ? 'no-padding-top' : ''; ?>">
                <?php stortech_pro_section_tooltip( 'product-design-class' ); ?>
                <div class="wrapper">
                    <?php foreach ( $content_details as $content ) :  ?>
                        <article class="<?php echo ! empty( $content['image'] ) ? 'has-post-thumbnail' : 'no-featured-image'; ?>">
                            <div class="entry-container">
                                <?php if ( ! empty( $content['title'] ) ) : ?>
                                    <header class="section-header">
                                        <h2 class="section-title"><?php echo esc_html( $content['title'] ); ?></h2>
                                    </header>
                                <?php endif; ?>                           

                                <?php if ( ! empty( $content['excerpt'] ) ) : ?>
                                    <div class="entry-content">
                                        <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                    </div><!-- .entry-content -->
                                <?php endif; ?>
                                <?php if ( !empty( $options['product_layout_design_btn_label'] ) && !empty( $options['product_layout_design_btn_url'] ) ) : ?>
                                    <div class="read-more">
                                        <a href="<?php echo esc_url($options['product_layout_design_btn_url'] ); ?>" class="btn btn-fill" > <?php echo esc_html( $options['product_layout_design_btn_label'] ) ?>
                                         <svg viewBox="0 0 443.52 443.52">
                                            <path d="M336.226,209.591l-204.8-204.8c-6.78-6.548-17.584-6.36-24.132,0.42c-6.388,6.614-6.388,17.099,0,23.712l192.734,192.734
                                            L107.294,414.391c-6.663,6.664-6.663,17.468,0,24.132c6.665,6.663,17.468,6.663,24.132,0l204.8-204.8
                                            C342.889,227.058,342.889,216.255,336.226,209.591z"/>
                                        </svg>                                     
                                        </a>
                                    </div>
                                <?php endif; ?>
                            </div><!-- .entry-container -->
                            <div class="featured-image" style="background-image:url('<?php echo esc_url( $content['image'] ); ?>')"></div>
                            
                        </article>
                    <?php endforeach;?>
                </div><!-- .wrapper -->
            </div><!-- #business-product_layout_design-us -->    
        </div>
              
<?php    }
endif;