<?php
/**
 * Product features section
 *
 * This is the template for the content of product_layout_features section
 *
 * @package Theme Palace
 * @subpackage Stortech Pro
 * @since Stortech Pro 1.0.0
 */
if ( ! function_exists( 'stortech_pro_add_product_layout_features_section' ) ) :
    /**
    * Add product_layout_features section
    *
    *@since Stortech Pro 1.0.0
    */
    function stortech_pro_add_product_layout_features_section() {
    	$options = stortech_pro_get_theme_options();
        // Check if product_layout_features is enabled on frontpage
        $product_layout_features_enable = apply_filters( 'stortech_pro_section_status', true, 'product_layout_features_section_enable' );
        
        if( !in_array( $options['home_layout'], array( 'product', 'first-design' ) ) ){
            $product_layout_features_enable = false;
        }

        if ( true !== $product_layout_features_enable ) {
            return false;
        }
        // Get product_layout_features section details
        $section_details = array();
        $section_details = apply_filters( 'stortech_pro_filter_product_layout_features_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render product_layout_features section now.
        stortech_pro_render_product_layout_features_section( $section_details );
    }
endif;

if ( ! function_exists( 'stortech_pro_get_product_layout_features_section_details' ) ) :
    /**
    * product_layout_features section details.
    *
    * @since Stortech Pro 1.0.0
    * @param array $input product_layout_features section details.
    */
    function stortech_pro_get_product_layout_features_section_details( $input ) {
        $options = stortech_pro_get_theme_options();

        // Content type.
        $product_layout_features_content_type  = $options['product_layout_features_content_type'];
        $product_layout_features_count = ! empty( $options['product_layout_features_count'] ) ? $options['product_layout_features_count'] : 3;
        
        $content = array();
        switch ( $product_layout_features_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $product_layout_features_count; $i++ ) {
                    if ( ! empty( $options['product_layout_features_content_page_' . $i] ) )
                        $page_ids[] = $options['product_layout_features_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $product_layout_features_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $product_layout_features_count; $i++ ) {
                    if ( ! empty( $options['product_layout_features_content_post_' . $i] ) )
                        $post_ids[] = $options['product_layout_features_content_post_' . $i];
                }
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $product_layout_features_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['product_layout_features_content_category'] ) ? $options['product_layout_features_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $product_layout_features_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = stortech_pro_trim_content( 25 );

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// product_layout_features section content details.
add_filter( 'stortech_pro_filter_product_layout_features_section_details', 'stortech_pro_get_product_layout_features_section_details' );


if ( ! function_exists( 'stortech_pro_render_product_layout_features_section' ) ) :
  /**
   * Start product_layout_features section
   *
   * @return string product_layout_features content
   * @since Stortech Pro 1.0.0
   *
   */
   function stortech_pro_render_product_layout_features_section( $content_details = array() ) {
        $options = stortech_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="stortech_pro_product_layout_features_section">   
                <div id="services" class="relative page-section product-features <?php $options['home_layout'] == 'product' ? 'no-padding-top' : ''; ?>">
            <?php stortech_pro_section_tooltip( 'product-features-class' ); ?>
                <div class="wrapper">
                    <?php if (!empty($options['product_layout_features_title']) || !empty($options['product_layout_features_subtitle'])): ?>
                        <div class="section-header">
                            <?php if (!empty($options['product_layout_features_title'])) : ?>
                                <h2 class="section-title"><?php echo esc_html( $options['product_layout_features_title'] ); ?></h2>
                            <?php endif; ?>
                            <?php if (!empty($options['product_layout_features_subtitle'])) : ?>
                                <p><?php echo esc_html( $options['product_layout_features_subtitle'] ); ?></p>
                            <?php endif; ?>
                        </div>
                            
                    <?php endif; ?>
                    <?php if (!empty( $options['product_layout_features_image'])): ?>
                        <div class="featured-image">
                            <img src=" <?php echo esc_url($options['product_layout_features_image']) ?>">
                        </div>
                    <?php endif ?>
                    <div class="section-content <?php echo esc_attr( $options['product_layout_features_column_layout'] ) ; ?> clear">
                        <?php $i =1 ; foreach ($content_details as $content): 
                        $icon    = isset($options['product_layout_features_content_icon_'.$i]) ? $options['product_layout_features_content_icon_'.$i] : '';
                        ?>
                            <article>
                                <div class="service-item-wrapper">
                                    <?php if ( $icon !== '' ): ?>
                                        <div class="service-icon">
                                            <a href="<?php echo esc_url( $content['url'] ) ; ?>"><i class="fa <?php echo esc_attr( $icon ) ; ?>"></i></a>
                                        </div><!-- .service-icon -->
                                    <?php endif ?>
                                    

                                    <div class="entry-container">
                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ) ; ?>"><?php echo esc_html( $content['title'] ) ; ?></a></h2>
                                        </header>

                                        <div class="entry-content">
                                            <p><?php echo esc_html( $content['excerpt'] ) ; ?></p>
                                        </div><!-- .entry-content -->
                                    </div><!-- .entry-container -->
                                </div><!-- .product_layout_features-item-wrapper -->
                            </article>
                        <?php $i++; endforeach ?>
                       
                    </div><!-- .col-3 -->
                </div><!-- .wrapper -->
            </div><!-- #our-product_layout_featuress -->
        </div>
       
        
    <?php }
endif;