<?php
/**
 * Accessories section
 *
 * This is the template for the content of product_layout_gallery section
 *
 * @package Theme Palace
 * @subpackage Stortech Pro
 * @since Stortech Pro 1.0.0
 */
if ( ! function_exists( 'stortech_pro_add_product_layout_gallery_section' ) ) :
    /**
    * Add product_layout_gallery section
    *
    *@since Stortech Pro 1.0.0
    */
    function stortech_pro_add_product_layout_gallery_section() {
        $options = stortech_pro_get_theme_options();
        // Check if product_layout_gallery is enabled on frontpage
        $product_layout_gallery_enable = apply_filters( 'stortech_pro_section_status', true, 'product_layout_gallery_section_enable' );

         if( !in_array( $options['home_layout'], array( 'product', 'first-design' ) ) ){
            $product_layout_gallery_enable = false;
        }

        if ( true !== $product_layout_gallery_enable ) {
            return false;
        }
        // Get product_layout_gallery section details
        $section_details = array();
        $section_details = apply_filters( 'stortech_pro_filter_product_layout_gallery_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render product_layout_gallery section now.
        stortech_pro_render_product_layout_gallery_section( $section_details );
    }
endif;

if ( ! function_exists( 'stortech_pro_get_product_layout_gallery_section_details' ) ) :
    /**
    * product_layout_gallery section details.
    *
    * @since Stortech Pro 1.0.0
    * @param array $input product_layout_gallery section details.
    */
    function stortech_pro_get_product_layout_gallery_section_details( $input ) {
        $options = stortech_pro_get_theme_options();

        // Content type.
        $product_layout_gallery_content_type  = $options['product_layout_gallery_content_type'];
        $product_layout_gallery_count = ! empty( $options['product_layout_gallery_count'] ) ? $options['product_layout_gallery_count'] : 3;
        
        $content = array();
        switch ( $product_layout_gallery_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $product_layout_gallery_count; $i++ ) {
                    if ( ! empty( $options['product_layout_gallery_content_page_' . $i] ) )
                        $page_ids[] = $options['product_layout_gallery_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $product_layout_gallery_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $product_layout_gallery_count; $i++ ) {
                    if ( ! empty( $options['product_layout_gallery_content_post_' . $i] ) )
                        $post_ids[] = $options['product_layout_gallery_content_post_' . $i];
                }
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $product_layout_gallery_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['product_layout_gallery_content_category'] ) ? $options['product_layout_gallery_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $product_layout_gallery_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = stortech_pro_trim_content( 15 );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// product_layout_gallery section content details.
add_filter( 'stortech_pro_filter_product_layout_gallery_section_details', 'stortech_pro_get_product_layout_gallery_section_details' );


if ( ! function_exists( 'stortech_pro_render_product_layout_gallery_section' ) ) :
  /**
   * Start product_layout_gallery section
   *
   * @return string product_layout_gallery content
   * @since Stortech Pro 1.0.0
   *
   */
   function stortech_pro_render_product_layout_gallery_section( $content_details = array() ) {
        $options = stortech_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="stortech_pro_product_layout_gallery_section">   
            <div id="camera-masonry" class="relative page-section product-gallery">
                <?php stortech_pro_section_tooltip( 'product-gallery-class' ); ?>
                <div class="wrapper">
                    <div class="grid clear"> 
                        <article class="grid-item" >
                            <?php if ($options['product_layout_gallery_title']): ?>
                                <header class="section-header">
                                    <h2 class="section-title"><?php echo esc_html( $options['product_layout_gallery_title'] ); ?></h2>
                                </header>
                            <?php endif ?>
                            <?php if ($options['product_layout_gallery_subtitle']): ?>
                                <div class="section-content">
                                   <p><?php echo esc_html( $options['product_layout_gallery_subtitle'] ); ?></p>
                                </div><!-- .entry-content-->  
                            <?php endif ?>                     
                        </article> 
                        <?php $i = 1 ; 
                        foreach ($content_details as $content): 
                        ?>
                        <article class="grid-item" >
                            <div class="featured-image" style="background-image:url('<?php echo esc_url( $content['image']);  ?>');">                    
                            </div><!-- .wrapper -->
                        </article>
                        <?php $i++; endforeach ; ?>
                    </div><!-- .grid --> 
                </div><!-- .wrapper -->
            </div><!-- #masonry -->
        </div>
       
                       
    <?php }
endif;