<?php
/**
 * product_layout_similar_product section
 *
 * This is the template for the content of product_layout_similar_product section
 *
 * @package Theme Palace
 * @subpackage Stortech Pro
 * @since Stortech Pro 1.0.0
 */
if ( ! function_exists( 'stortech_pro_add_product_layout_similar_product_section' ) ) :
    /**
    * Add product_layout_similar_product section
    *
    *@since Stortech Pro 1.0.0
    */
    function stortech_pro_add_product_layout_similar_product_section() {
    	$options = stortech_pro_get_theme_options();
        // Check if product_layout_similar_product is enabled on frontpage
        $product_layout_similar_product_enable = apply_filters( 'stortech_pro_section_status', true, 'product_layout_similar_product_section_enable' );

        if( !($options['home_layout'] == 'product')    ){
            $product_layout_similar_product_enable = false;
        }

        if ( true !== $product_layout_similar_product_enable ) {
            return false;
        }
        // Get product_layout_similar_product section details
        $section_details = array();
        $section_details = apply_filters( 'stortech_pro_filter_product_layout_similar_product_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }
        if ( !class_exists('WooCommerce') ) {
            return;
        }
        // Render product_layout_similar_product section now.
        stortech_pro_render_product_layout_similar_product_section( $section_details );
    }
endif;

if ( ! function_exists( 'stortech_pro_get_product_layout_similar_product_section_details' ) ) :
    /**
    * product_layout_similar_product section details.
    *
    * @since Stortech Pro 1.0.0
    * @param array $input product_layout_similar_product section details.
    */
    function stortech_pro_get_product_layout_similar_product_section_details( $input ) {
        $options = stortech_pro_get_theme_options();

        // Content type.
        $product_layout_similar_product_content_type  = $options['product_layout_similar_product_content_type'];     
        $product_layout_similar_product_count = ! empty( $options['product_layout_similar_product_count'] ) ? $options['product_layout_similar_product_count'] : 3;
        $product_layout_similar_product_event_count = ! empty( $options['product_layout_similar_product_event_count'] ) ? $options['product_layout_similar_product_event_count'] : 3;
        
        $content = array();
        $content = array();
        switch ( $product_layout_similar_product_content_type ) {

            case 'recent_product':
                $args = array(
                    'post_type'             => 'product',
                    'posts_per_page'        => $product_layout_similar_product_count,
                    'ignore_sticky_posts'   => true,
                    );
            break;

            case 'product':
                $page_ids = array();

                for ( $i = 1; $i <= $product_layout_similar_product_count; $i++ ) {
                    if ( ! empty( $options['product_layout_similar_product_content_page_' . $i] ) )
                        $page_ids[] = $options['product_layout_similar_product_content_page_' . $i];
                }

                $args = array(
                    'post_type'         => 'product',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => count( $page_ids ),
                    'orderby'           => 'post__in',
                    );
            break;
            case 'product_cat':
                $cat_id = ! empty( $options['product_layout_similar_product_category'] ) ? $options['product_layout_similar_product_category'] : '';

                $args = array(
                'post_type'         => 'product',
                'posts_per_page'    => absint( $product_layout_similar_product_count ),
                'tax_query'         => array(
                    array(
                        'taxonomy'  => 'product_cat',
                        'field'     => 'id',
                        'terms'     => $cat_id
                    )
                ) );
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = stortech_pro_trim_content( 20 );
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : '';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        
    
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// product_layout_similar_product section content details.
add_filter( 'stortech_pro_filter_product_layout_similar_product_section_details', 'stortech_pro_get_product_layout_similar_product_section_details' );


if ( ! function_exists( 'stortech_pro_render_product_layout_similar_product_section' ) ) :
  /**
   * Start product_layout_similar_product section
   *
   * @return string product_layout_similar_product content
   * @since Stortech Pro 1.0.0
   *
   */
   function stortech_pro_render_product_layout_similar_product_section( $content_details = array() ) {
        $options = stortech_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="stortech_pro_product_layout_similar_product_section">   
            <div id="similar-product" class="page-section no-padding-top">
                <?php stortech_pro_section_tooltip( 'similar-product' ); ?>
                    <div class="wrapper">
                        <div class="section-header">
                            <h2 class="section-title"><?php echo esc_html( $options['product_layout_similar_product_title'] ) ; ?></h2>
                        </div><!-- .section-header -->

                        <div class="section-content">
                            <ul class="products col-3">
                                <?php foreach ( $content_details as $content ): 
                                    $image = $content['image'] == '' ? get_template_directory_uri().'/assets/uploads/no-featured-image-590x650.jpg' : $content['image'] ;
                                ?>
                                    <li class="product has-post-thumbnail sale">
                                        <div class="post-thumbnail">
                                            <a href="<?php echo esc_url( $content['url'] ) ; ?>" class="woocommerce-LoopProduct-link woocommerce-loop-product__link">
                                            <?php 
                                                $product = new WC_Product( $content['id'] );
                                                if ( $product->get_sale_price() ): 
                                            ?>
                                            <span class="onsale">
                                                <?php esc_html_e('Sale!', 'stortech-pro'); ?>
                                            </span>
                                            <?php endif ?>
                                            <img width="330" height="400" src="<?php echo esc_url($image); ?>">
                                            </a>
                                        </div><!-- .post-thumbnail -->
                                        <div class="product_meta">
                                            <?php 
                                                $terms = get_the_terms ( $content['id'], 'product_cat' );
                                                foreach ( $terms as $term ) { ?>
                                                    <div class="cat-links">
                                                        <a href="<?php echo esc_url( get_term_link( $term->term_id, 'product_cat' ) ) ?>"><?php echo esc_html( $term->name) ; ?></a>
                                                    </div><!-- .posted_in -->
                                                   
                                                <?php }
                                            ?>
                                        </div><!-- .product-meta -->
                                            <a href="<?php echo esc_url( $content['url'] ) ; ?>"><h2 class="woocommerce-loop-product__title"><?php echo esc_html( $content['title'] ) ?></h2></a>
                                            <span class="price">
                                                 <?php 
                                                    $product = new WC_Product( $content['id'] );
                                                    echo $product->get_price_html();
                                                ?>
                                            </span>
                                        
                                    </li>
                                <?php endforeach ?>
                            </ul><!-- .product-slider -->                        
                            <?php if ( !empty( $options['product_layout_similar_btn_label'] ) && !empty( $options['product_layout_similar_btn_url'] ) ) : ?>
                                <div class="read-more">
                                    <a href="<?php echo esc_url($options['product_layout_similar_btn_url'] ); ?>" class="btn btn-fill" > <?php echo esc_html( $options['product_layout_similar_btn_label'] ) ?>                                  
                                    </a>
                                </div>
                            <?php endif; ?>
                        </div><!-- .section-content -->
                    </div><!-- .wrapper -->
                </div>
        </div>
     
    <?php }
endif;