<?php
/**
 * Testimonial section
 *
 * This is the template for the content of testimonial section
 *
 * @package Theme Palace
 * @subpackage Stortech Pro
 * @since Stortech Pro 1.0.0
 */
if ( ! function_exists( 'stortech_pro_add_testimonial_section' ) ) :
    /**
    * Add testimonial section
    *
    *@since Stortech Pro 1.0.0
    */
    function stortech_pro_add_testimonial_section() {
        $options = stortech_pro_get_theme_options();
        // Check if testimonial is enabled on frontpage
        $testimonial_enable = apply_filters( 'stortech_pro_section_status', true, 'testimonial_section_enable' );

        if( !($options['home_layout'] == 'first-design')    ){
            $testimonial_enable = false;
        }

        if ( true !== $testimonial_enable ) {
            return false;
        }
        // Get testimonial section details
        $section_details = array();
        $section_details = apply_filters( 'stortech_pro_filter_testimonial_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render testimonial section now.
        stortech_pro_render_testimonial_section( $section_details );
    }
endif;

if ( ! function_exists( 'stortech_pro_get_testimonial_section_details' ) ) :
    /**
    * testimonial section details.
    *
    * @since Stortech Pro 1.0.0
    * @param array $input testimonial section details.
    */
    function stortech_pro_get_testimonial_section_details( $input ) {
        $options = stortech_pro_get_theme_options();

        // Content type.
        $testimonial_content_type  = $options['testimonial_content_type'];
   
        $testimonial_count = ! empty( $options['testimonial_count'] ) ? $options['testimonial_count'] : 3;

        
        $content = array();

        switch ( $testimonial_content_type ) {
            
            case 'page':
                $page_ids = array();
                $position = array();

                for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                    if ( ! empty( $options['testimonial_content_page_' . $i] ) ) :
                        $page_ids[] = $options['testimonial_content_page_' . $i];
                        $position[] = ! empty( $options['testimonial_position_' . $i] ) ? $options['testimonial_position_' . $i] : '';
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $testimonial_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();
                $position = array();

                for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                    if ( ! empty( $options['testimonial_content_post_' . $i] ) ) :
                        $post_ids[] = $options['testimonial_content_post_' . $i];
                        $position[] = ! empty( $options['testimonial_position_' . $i] ) ? $options['testimonial_position_' . $i] : '';
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $testimonial_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'custom':
                for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                    $custom['title']        = ! empty( $options['testimonial_title_' . $i] ) ? $options['testimonial_title_' . $i] : '';
                    $custom['excerpt']      = ! empty( $options['testimonial_description_' . $i] ) ? $options['testimonial_description_' . $i] : '';
                    $custom['image']        = ! empty( $options['testimonial_image_' . $i] ) ? $options['testimonial_image_' . $i] : '';
                    $custom['url']          = ! empty( $options['testimonial_link_' . $i] ) ? $options['testimonial_link_' . $i] : '';
                    $custom['position']     = ! empty( $options['testimonial_position_' . $i] ) ? $options['testimonial_position_' . $i] : '';


                    // Push to the main array.
                    array_push( $content, $custom );
                }
            break;


            default:
            break;
        }

        if ( 'custom' !== $testimonial_content_type ) {
            // Run The Loop.
            $query = new WP_Query( $args );
            $i = 0;
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['position']  = ( $testimonial_content_type !== 'tp-testimonial'  && ! empty( $position[$i] ) ) ? $position[$i] : '';
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = stortech_pro_trim_content( 20 );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id() ) : 'full';

                    // Push to the main array.
                    array_push( $content, $page_post );
                    $i++;
                endwhile;
            endif;
            wp_reset_postdata();
        }

       
        
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// testimonial section content details.
add_filter( 'stortech_pro_filter_testimonial_section_details', 'stortech_pro_get_testimonial_section_details' );


if ( ! function_exists( 'stortech_pro_render_testimonial_section' ) ) :
  /**
   * Start testimonial section
   *
   * @return string testimonial content
   * @since Stortech Pro 1.0.0
   *
   */
   function stortech_pro_render_testimonial_section( $content_details = array() ) {
        $options = stortech_pro_get_theme_options();
        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="stortech_pro_testimonial_section">   
             <div id="testimonials" class="page-section">
                <?php stortech_pro_section_tooltip( 'testimonials' ); ?>
                <div class="wrapper">
                    <div class="testimonail-wrapper col-3">
                        <?php $i = 1 ; 
                        foreach ( $content_details as $content ) : 
                            $image = $content['image'] == '' ? get_template_directory_uri().'/assets/uploads/no-featured-image-590x650.jpg' : $content['image'] ;
                            $position = isset($options['testimonial_position_'.$i]) ? $options['testimonial_position_'.$i] : __(' Happy Client', 'stortech-pro' );
                        ?>
                            <article class="hentry">
                                    <div class="featured-image">
                                        <a href="<?php echo esc_url( $content['url'] ) ; ?>">
                                            <img src="<?php echo esc_url( $image ) ; ?>">
                                        </a>
                                    </div><!-- .featured-image -->

                                    <div class="entry-container">
                                        <div class="entry-content">
                                            <p><?php echo esc_html( $content['excerpt'] ) ; ?></p>
                                        </div><!-- .entry-content -->
                                        <div class="seperator"></div>
                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ) ; ?>"><?php echo esc_html( $content['title'] ) ; ?> 
                                            <?php if (!empty($position)): ?>   
                                                ,<?php echo esc_html( $position ) ; ?>
                                            <?php endif ?>
                                            </a></h2>  
                                        </header>
                                    </div><!-- .entry-container -->
                            </article>
                        <?php $i++; endforeach ?>
                    </div><!-- .testimonial-wrapper -->
                </div><!-- .wrapper -->
            </div><!-- #testimonial-section -->
        </div>
       
    <?php }
endif;
