<?php
/**
 * Theme Palace basic theme structure hooks
 *
 * This file contains structural hooks.
 *
 * @package Theme Palace
 * @subpackage Stortech Pro
 * @since Stortech Pro 1.0.0
 */

$options = stortech_pro_get_theme_options();


if ( ! function_exists( 'stortech_pro_doctype' ) ) :
	/**
	 * Doctype Declaration.
	 *
	 * @since Stortech Pro 1.0.0
	 */
	function stortech_pro_doctype() {
	?>
		<!DOCTYPE html>
			<html <?php language_attributes(); ?>>
	<?php
	}
endif;

add_action( 'stortech_pro_doctype', 'stortech_pro_doctype', 10 );


if ( ! function_exists( 'stortech_pro_head' ) ) :
	/**
	 * Header Codes
	 *
	 * @since Stortech Pro 1.0.0
	 *
	 */
	function stortech_pro_head() {
		?>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
		<link rel="profile" href="http://gmpg.org/xfn/11">
		<?php if ( is_singular() && pings_open( get_queried_object() ) ) : ?>
			<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
		<?php endif;
	}
endif;
add_action( 'stortech_pro_before_wp_head', 'stortech_pro_head', 10 );

if ( ! function_exists( 'stortech_pro_page_start' ) ) :
	/**
	 * Page starts html codes
	 *
	 * @since Stortech Pro 1.0.0
	 *
	 */
	function stortech_pro_page_start() {
		?>
		<div id="page" class="site">
			<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'stortech-pro' ); ?></a>

		<?php
	}
endif;
add_action( 'stortech_pro_page_start_action', 'stortech_pro_page_start', 10 );


if ( ! function_exists( 'stortech_pro_header_start' ) ) :
	/**
	 * Header start html codes
	 *
	 * @since Stortech Pro 1.0.0
	 *
	 */
	function stortech_pro_header_start() {
		?>
		<div class="menu-overlay"></div>
		<div id="site-menu" class="header-menu">
			<?php
			$options  = stortech_pro_get_theme_options();
			?>
				<div id="news" class="relative">
		            <div class="wrapper">
		                <span><?php echo esc_html( $options['news_notice_title'] ) ; ?></span>
		            </div><!-- .wrapper -->
		        </div><!-- #news -->		
			<header id="masthead" class="site-header" role="banner">
		<?php
	}
endif;
add_action( 'stortech_pro_header_action', 'stortech_pro_header_start', 20 );

if ( ! function_exists( 'stortech_pro_page_end' ) ) :
	/**
	 * Page end html codes
	 *
	 * @since Stortech Pro 1.0.0
	 *
	 */
	function stortech_pro_page_end() {
		?>
		</div><!-- #page -->
		<?php
	}
endif;
add_action( 'stortech_pro_page_end_action', 'stortech_pro_page_end', 10 );

if ( ! function_exists( 'stortech_pro_site_branding' ) ) :
	/**
	 * Site branding codes
	 *
	 * @since Stortech Pro 1.0.0
	 *
	 */
	function stortech_pro_site_branding() {
		$options  = stortech_pro_get_theme_options();
		$header_txt_logo_extra = $options['header_txt_logo_extra'];		
		?>
		<div class="wrapper">
			<div class="site-menu">
				<div class="site-branding">
					<?php if ( in_array( $header_txt_logo_extra, array( 'show-all', 'logo-title', 'logo-tagline' ) )  ) { ?>
						<div class="site-logo">
							<?php the_custom_logo(); ?>
						</div>
					<?php } 
					if ( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title', 'show-all', 'tagline-only', 'logo-tagline' ) ) ) : ?>
						<div id="site-identity">
							<?php
							if( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title' ) )  ) {
								if ( stortech_pro_is_latest_posts() ) : ?>
									<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
								<?php else : ?>
									<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
								<?php
								endif;
							} 
							if ( in_array( $header_txt_logo_extra, array( 'show-all', 'tagline-only', 'logo-tagline' ) ) ) {
								$description = get_bloginfo( 'description', 'display' );
								if ( $description || is_customize_preview() ) : ?>
									<p class="site-description"><?php echo esc_html( $description ); /* WPCS: xss ok. */ ?></p>
								<?php
								endif; 
							}?>
						</div>
					<?php endif; ?>
				</div><!-- .site-branding -->
		<?php
	}
endif;
add_action( 'stortech_pro_header_action', 'stortech_pro_site_branding', 20 );

if ( ! function_exists( 'stortech_pro_site_navigation' ) ) :
	/**
	 * Site navigation codes
	 *
	 * @since Stortech Pro 1.0.0
	 *
	 */
	function stortech_pro_site_navigation() {
		$options = stortech_pro_get_theme_options();
		?>
		<nav id="site-navigation" class="main-navigation" role="navigation">
			<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
				<span class="menu-label"><?php esc_html_e( 'Menu', 'stortech-pro' ); ?></span>
				<?php
				echo stortech_pro_get_svg( array( 'icon' => 'menu' ) );
				echo stortech_pro_get_svg( array( 'icon' => 'close' ) );
				?>					
			</button>

			<?php  
				
                $search = '';
				if ( $options['nav_search_enable'] ) :
					$search = '<li class="search-menu"><a href="#">';
					$search .= stortech_pro_get_svg( array( 'icon' => 'search' ) );
					$search .= stortech_pro_get_svg( array( 'icon' => 'close' ) );
					$search .= '</a><div id="search">';
					$search .= get_search_form( $echo = false );
	                $search .= '</div><!-- #search --></li>';
                endif;
        	
        		wp_nav_menu( array(
        			'theme_location' => 'primary',
        			'container' => 'div',
        			'menu_class' => 'menu nav-menu',
        			'menu_id' => 'primary-menu',
        			'echo' => true,
        			'fallback_cb' => 'stortech_pro_menu_fallback_cb',
        			'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s' . $search . '</ul>',
        		) );
        	?>
		</nav><!-- #site-navigation -->
		</div>
		<?php if ( class_exists('WooCommerce') ): ?>
			<div id="login-register">
	            <ul>
	                <li>
						<a href=" <?php echo get_permalink( get_option('woocommerce_myaccount_page_id') ) ?>">
							<?php echo stortech_pro_get_svg( array( 'icon' => 'user' ) ); ?>
						</a>
	                </li>
	                
		   			<li class="cart-count">
		       		 	<a href="<?php echo wc_get_cart_url(); ?>">
		       		 		<?php 
		       		 			if ( WC()->cart->get_cart_contents_count() > 0 ) {
		       		 				echo '('.WC()->cart->get_cart_contents_count().')';
		       		 			 }
		       		 			echo stortech_pro_get_svg( array( 'icon' => 'cart' ) ); 
		       		 		?>
		           		</a>
		            </li>
		           	
		    	</ul>
	        </div><!-- .social-icons -->
        <?php  endif ; ?> 
		</div><!-- .wrapper -->
		<?php
	}
endif;
add_action( 'stortech_pro_header_action', 'stortech_pro_site_navigation', 30 );


if ( ! function_exists( 'stortech_pro_header_end' ) ) :
	/**
	 * Header end html codes
	 *
	 * @since Stortech Pro 1.0.0
	 *
	 */
	function stortech_pro_header_end() {
		?>
		</header><!-- #masthead -->
		
		<?php
	}
endif;

add_action( 'stortech_pro_header_action', 'stortech_pro_header_end', 50 );

if ( ! function_exists( 'stortech_pro_content_start' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Stortech Pro 1.0.0
	 *
	 */
	function stortech_pro_content_start() {
		?>
		<div id="content" class="site-content stortech-pro-sortable-list">
		<?php
	}
endif;
add_action( 'stortech_pro_content_start_action', 'stortech_pro_content_start', 10 );

if ( ! function_exists( 'stortech_pro_header_image' ) ) :
	/**
	 * Header Image codes
	 *
	 * @since Stortech Pro 1.0.0
	 *
	 */
	function stortech_pro_header_image() {
		if ( stortech_pro_is_frontpage() )
			return;
		$header_image = get_header_image();
		$class = '';
		if ( is_singular() ) :
			$class = ( has_post_thumbnail() || ! empty( $header_image ) ) ? '' : 'header-media-disabled';
		else :
			$class = ! empty( $header_image ) ? '' : 'header-media-disabled';
		endif;
		
		if ( is_singular() && has_post_thumbnail() ) : 
			$header_image = get_the_post_thumbnail_url( get_the_id(), 'full' );
    	endif; ?>

    	<div id="page-site-header" class="relative <?php echo esc_attr( $class ); ?>" style="background-image: url('<?php echo esc_url( $header_image ); ?>');">
            <div class="overlay"></div>
            <div class="wrapper">
                <header class="page-header">
                    <?php stortech_pro_custom_header_banner_title(); ?>
                </header>

                <?php stortech_pro_add_breadcrumb(); ?>
            </div><!-- .wrapper -->
        </div><!-- #page-site-header -->

	<?php
	}
endif;
add_action( 'stortech_pro_header_image_action', 'stortech_pro_header_image', 10 );

if ( ! function_exists( 'stortech_pro_add_breadcrumb' ) ) :
	/**
	 * Add breadcrumb.
	 *
	 * @since Stortech Pro 1.0.0
	 */
	function stortech_pro_add_breadcrumb() {
		$options = stortech_pro_get_theme_options();
		// Bail if Breadcrumb disabled.
		$breadcrumb = $options['breadcrumb_enable'];
		if ( false === $breadcrumb ) {
			return;
		}
		
		// Bail if Home Page.
		if ( stortech_pro_is_frontpage() ) {
			return;
		}

		echo '<div id="breadcrumb-list" >';
				/**
				 * stortech_pro_simple_breadcrumb hook
				 *
				 * @hooked stortech_pro_simple_breadcrumb -  10
				 *
				 */
				do_action( 'stortech_pro_simple_breadcrumb' );
		echo '</div><!-- #breadcrumb-list -->';
		return;
	}
endif;
add_action( 'stortech_pro_header_image_action', 'stortech_pro_add_breadcrumb', 20 );

if ( ! function_exists( 'stortech_pro_content_end' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Stortech Pro 1.0.0
	 *
	 */
	function stortech_pro_content_end() {
		?>
		</div><!-- #content -->
		<?php
	}
endif;
add_action( 'stortech_pro_content_end_action', 'stortech_pro_content_end', 10 );

if ( ! function_exists( 'stortech_pro_footer_start' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Stortech Pro 1.0.0
	 *
	 */
	function stortech_pro_footer_start() {
		?>
		<footer id="colophon" class="site-footer" role="contentinfo">
		<?php
	}
endif;
add_action( 'stortech_pro_footer', 'stortech_pro_footer_start', 10 );

if ( ! function_exists( 'stortech_pro_footer_site_info' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Stortech Pro 1.0.0
	 *
	 */
	function stortech_pro_footer_site_info() {
		$options = stortech_pro_get_theme_options();
		$search = array( '[the-year]', '[site-link]' );

        $replace = array( date( 'Y' ), '<a href="'. esc_url( home_url( '/' ) ) .'">'. esc_attr( get_bloginfo( 'name', 'display' ) ) . '</a>' );

        $options['copyright_text'] = str_replace( $search, $replace, $options['copyright_text'] );
        //$options['powered_by_text'] = str_replace( $search, $replace, $options['powered_by_text'] );

		$copyright_text = $options['copyright_text']; 
		//$powered_by_text = $options['powered_by_text'];
		?>
		<div class="site-info col-2">
                <div class="wrapper">
                	<div class="custom-menu">
                        <span><?php 
                    	echo stortech_pro_santize_allow_tag( $copyright_text ); 
                    	if ( function_exists( 'the_privacy_policy_link' ) ) {
							the_privacy_policy_link( ' | ' );
						}
                    	?></span>
                    	<?php if ($options['footer_menu_enable']==true): ?>
	                   
	                    	<?php  
								wp_nav_menu(
									array(
										'theme_location' => 'footer',
										'echo' => true,
										'fallback_cb' => 'stortech_pro_menu_fallback_cb',
										'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s</ul>',
										)
									);
					        		
					        	?>
                    	<?php endif ?> 
                    </div>
                    <?php if ($options['footer_social_enable']==true): ?>
	                   
	                    <?php
							wp_nav_menu( 
								array(
									'theme_location' => 'social',
									'container' => 'ul',
									'container_class' => 'social-icons',
									'menu_class' => 'social-icons',
									'echo' => true,
									'link_before' => '<span class="screen-reader-text">',
									'link_after' => '</span>',
									)
								);
						?><!-- .social-menu -->
					<?php endif; ?>
                </div><!-- .wrapper -->    
            </div><!-- .site-info -->

		<?php
	}
endif;
add_action( 'stortech_pro_footer', 'stortech_pro_footer_site_info', 40 );

if ( ! function_exists( 'stortech_pro_footer_scroll_to_top' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Stortech Pro 1.0.0
	 *
	 */
	function stortech_pro_footer_scroll_to_top() {
		$options  = stortech_pro_get_theme_options();
		if ( true === $options['scroll_top_visible'] ) : ?>
			<div class="backtotop"><?php echo stortech_pro_get_svg( array( 'icon' => 'up' ) ); ?></div>
		<?php endif;
	}
endif;
add_action( 'stortech_pro_footer', 'stortech_pro_footer_scroll_to_top', 40 );

if ( ! function_exists( 'stortech_pro_footer_end' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Stortech Pro 1.0.0
	 *
	 */
	function stortech_pro_footer_end() {
		?>
		</footer>
		<div class="popup-overlay"></div>
		<?php
	}
endif;
add_action( 'stortech_pro_footer', 'stortech_pro_footer_end', 100 );

if ( ! function_exists( 'stortech_pro_loader' ) ) :
	/**
	 * Start div id #loader
	 *
	 * @since Stortech Pro 1.0.0
	 *
	 */
	function stortech_pro_loader() {
		$options = stortech_pro_get_theme_options();
		if ( $options['loader_enable'] ) { ?>

			<div id="loader">
            <div class="loader-container">
            	<?php if ( 'default' == $options['loader_icon'] ) : ?>
	                <div id="preloader">
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                </div>
	            <?php else :
	            	echo stortech_pro_get_svg( array( 'icon' => esc_attr( $options['loader_icon'] ) ) );
	            endif; ?>
            </div>
        </div><!-- #loader -->
		<?php }
	}
endif;
add_action( 'stortech_pro_before_header', 'stortech_pro_loader', 10 );

if ( ! function_exists( 'stortech_pro_infinite_loader_spinner' ) ) :
	/**
	 *
	 * @since Stortech Pro 1.0.0
	 *
	 */
	function stortech_pro_infinite_loader_spinner() { 
		$id = get_the_ID();
		$options = stortech_pro_get_theme_options();
		if ( $options['pagination_type'] == 'infinite' ) :
			if ( ! empty($id) ) {
				echo '<div class="blog-loader">' . stortech_pro_get_svg( array( 'icon' => 'spinner-umbrella' ) ) . '</div>';
			}
		endif;
	}
endif;
add_action( 'stortech_pro_infinite_loader_spinner_action', 'stortech_pro_infinite_loader_spinner', 10 );